@@ -41,28 +41,36 @@
  *    By the same token, the GET_DATA_*() and SET_DATA_*() macro
  *    accessors now cast the input ptr to (l_uint32 *) for 1, 2 and 4 bpp.
  *    This allows them to take a (void *)lineptr.
+ *
+ *    In this test, we reconstruct pixs in different ways, pretending
+ *    that it is composed of pixels of sizes 1, 2, 4, 8, 16 and 32 bpp.
+ *    We also add irrelevant high order bits to the values, testing that
+ *    masking is done properly depending on the pixel size.
  */
 
 #include "allheaders.h"
 
-static l_int32 compareResults(PIX *pixs, PIX *pixt1, PIX *pixt2,
-                              l_int32 count1, l_int32 count2,
-                              const char *descr);
+static void CompareResults(PIX *pixs, PIX *pix1, PIX *pix2,
+                           l_int32 count1, l_int32 count2,
+                           const char *descr, L_REGPARAMS *rp);
 
 int main(int    argc,
          char **argv)
 {
-l_int32    i, j, k, w, h, w2, w4, w8, w16, w32, wpl, nerrors;
-l_int32    count1, count2, count3, ret, val1, val2;
-l_uint32   val32;
-l_uint32  *data, *line, *line2, *data2;
-void     **lines1, **linet1, **linet2;
-PIX       *pixs, *pixt1, *pixt2;
+l_int32       i, j, k, w, h, w2, w4, w8, w16, w32, wpl;
+l_int32       count1, count2, count3;
+l_uint32      val32, val1, val2;
+l_uint32     *data1, *line1, *data2, *line2;
+void        **lines1, **linet1, **linet2;
+PIX          *pixs, *pix1, *pix2;
+L_REGPARAMS  *rp;
 
-    setLeptDebugOK(1);
-    pixs = pixRead("feyn.tif");   /* width divisible by 16 */
+    if (regTestSetup(argc, argv, &rp))
+        return 1;
+
+    pixs = pixRead("feyn-fract.tif");
     pixGetDimensions(pixs, &w, &h, NULL);
-    data = pixGetData(pixs);
+    data1 = pixGetData(pixs);
     wpl = pixGetWpl(pixs);
     lines1 = pixGetLinePtrs(pixs, NULL);
 
@@ -84,9 +92,9 @@ PIX       *pixs, *pixt1, *pixt2;
     for (k = 0; k < 10; k++) {
         count2 = 0;
         for (i = 0; i < h; i++) {
-            line = data + i * wpl;
+            line1 = data1 + i * wpl;
             for (j = 0; j < w; j++) {
-               if (l_getDataBit(line, j))
+               if (l_getDataBit(line1, j))
                     count2++;
             }
         }
@@ -107,15 +115,15 @@ PIX       *pixs, *pixt1, *pixt2;
     fprintf(stderr, "Time with pixGetPixel() = %5.3f sec, count3 = %d\n",
             stopTimer(), count3);
 
-    pixt1 = pixCreateTemplate(pixs);
-    linet1 = pixGetLinePtrs(pixt1, NULL);
-    pixt2 = pixCreateTemplate(pixs);
-    data2 = pixGetData(pixt2);
-    linet2 = pixGetLinePtrs(pixt2, NULL);
+    pix1 = pixCreateTemplate(pixs);
+    linet1 = pixGetLinePtrs(pix1, NULL);
+    pix2 = pixCreateTemplate(pixs);
+    data2 = pixGetData(pix2);
+    linet2 = pixGetLinePtrs(pix2, NULL);
 
-    nerrors = 0;
-
-        /* Test different methods for 1 bpp */
+        /* ------------------------------------------------- */
+        /*           Test different methods for 1 bpp        */
+        /* ------------------------------------------------- */
     count1 = 0;
     for (i = 0; i < h; i++) {
         for (j = 0; j < w; j++) {
@@ -126,18 +134,19 @@ PIX       *pixs, *pixt1, *pixt2;
     }
     count2 = 0;
     for (i = 0; i < h; i++) {
-        line = data + i * wpl;
+        line1 = data1 + i * wpl;
         line2 = data2 + i * wpl;
         for (j = 0; j < w; j++) {
-            val2 = l_getDataBit(line, j);
+            val2 = l_getDataBit(line1, j);
             count2 += val2;
             if (val2) l_setDataBit(line2, j);
         }
     }
-    ret = compareResults(pixs, pixt1, pixt2, count1, count2, "1 bpp");
-    nerrors += ret;
+    CompareResults(pixs, pix1, pix2, count1, count2, "1 bpp", rp);
 
-        /* Test different methods for 2 bpp */
+        /* ------------------------------------------------- */
+        /*           Test different methods for 2 bpp        */
+        /* ------------------------------------------------- */
     count1 = 0;
     w2 = w / 2;
     for (i = 0; i < h; i++) {
@@ -150,19 +159,20 @@ PIX       *pixs, *pixt1, *pixt2;
     }
     count2 = 0;
     for (i = 0; i < h; i++) {
-        line = data + i * wpl;
+        line1 = data1 + i * wpl;
         line2 = data2 + i * wpl;
         for (j = 0; j < w2; j++) {
-            val2 = l_getDataDibit(line, j);
+            val2 = l_getDataDibit(line1, j);
             count2 += val2;
             val2 += 0xbbbbbbbc;
             l_setDataDibit(line2, j, val2);
         }
     }
-    ret = compareResults(pixs, pixt1, pixt2, count1, count2, "2 bpp");
-    nerrors += ret;
+    CompareResults(pixs, pix1, pix2, count1, count2, "2 bpp", rp);
 
-        /* Test different methods for 4 bpp */
+        /* ------------------------------------------------- */
+        /*           Test different methods for 4 bpp        */
+        /* ------------------------------------------------- */
     count1 = 0;
     w4 = w / 4;
     for (i = 0; i < h; i++) {
@@ -175,19 +185,20 @@ PIX       *pixs, *pixt1, *pixt2;
     }
     count2 = 0;
     for (i = 0; i < h; i++) {
-        line = data + i * wpl;
+        line1 = data1 + i * wpl;
         line2 = data2 + i * wpl;
         for (j = 0; j < w4; j++) {
-            val2 = l_getDataQbit(line, j);
+            val2 = l_getDataQbit(line1, j);
             count2 += val2;
             val2 += 0xbbbbbbb0;
             l_setDataQbit(line2, j, val2);
         }
     }
-    ret = compareResults(pixs, pixt1, pixt2, count1, count2, "4 bpp");
-    nerrors += ret;
+    CompareResults(pixs, pix1, pix2, count1, count2, "4 bpp", rp);
 
-        /* Test different methods for 8 bpp */
+        /* ------------------------------------------------- */
+        /*           Test different methods for 8 bpp        */
+        /* ------------------------------------------------- */
     count1 = 0;
     w8 = w / 8;
     for (i = 0; i < h; i++) {
@@ -200,19 +211,20 @@ PIX       *pixs, *pixt1, *pixt2;
     }
     count2 = 0;
     for (i = 0; i < h; i++) {
-        line = data + i * wpl;
+        line1 = data1 + i * wpl;
         line2 = data2 + i * wpl;
         for (j = 0; j < w8; j++) {
-            val2 = l_getDataByte(line, j);
+            val2 = l_getDataByte(line1, j);
             count2 += val2;
             val2 += 0xbbbbbb00;
             l_setDataByte(line2, j, val2);
         }
     }
-    ret = compareResults(pixs, pixt1, pixt2, count1, count2, "8 bpp");
-    nerrors += ret;
+    CompareResults(pixs, pix1, pix2, count1, count2, "8 bpp", rp);
 
-        /* Test different methods for 16 bpp */
+        /* ------------------------------------------------- */
+        /*          Test different methods for 16 bpp        */
+        /* ------------------------------------------------- */
     count1 = 0;
     w16 = w / 16;
     for (i = 0; i < h; i++) {
@@ -225,19 +237,20 @@ PIX       *pixs, *pixt1, *pixt2;
     }
     count2 = 0;
     for (i = 0; i < h; i++) {
-        line = data + i * wpl;
+        line1 = data1 + i * wpl;
         line2 = data2 + i * wpl;
         for (j = 0; j < w16; j++) {
-            val2 = l_getDataTwoBytes(line, j);
+            val2 = l_getDataTwoBytes(line1, j);
             count2 += val2;
             val2 += 0xbbbb0000;
             l_setDataTwoBytes(line2, j, val2);
         }
     }
-    ret = compareResults(pixs, pixt1, pixt2, count1, count2, "16 bpp");
-    nerrors += ret;
+    CompareResults(pixs, pix1, pix2, count1, count2, "16 bpp", rp);
 
-        /* Test different methods for 32 bpp */
+        /* ------------------------------------------------- */
+        /*          Test different methods for 32 bpp        */
+        /* ------------------------------------------------- */
     count1 = 0;
     w32 = w / 32;
     for (i = 0; i < h; i++) {
@@ -249,62 +262,40 @@ PIX       *pixs, *pixt1, *pixt2;
     }
     count2 = 0;
     for (i = 0; i < h; i++) {
-        line = data + i * wpl;
+        line1 = data1 + i * wpl;
         line2 = data2 + i * wpl;
         for (j = 0; j < w32; j++) {
-            val2 = l_getDataFourBytes(line, j);
+            val2 = l_getDataFourBytes(line1, j);
             count2 += val2 & 0xfff;
             l_setDataFourBytes(line2, j, val2);
         }
     }
-    ret = compareResults(pixs, pixt1, pixt2, count1, count2, "32 bpp");
-    nerrors += ret;
-
-    if (!nerrors)
-        fprintf(stderr, "****  No errors  ****\n");
-    else
-        fprintf(stderr, "****  %d errors found!  ****\n", nerrors);
-
+    CompareResults(pixs, pix1, pix2, count1, count2, "32 bpp", rp);
     pixDestroy(&pixs);
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
     lept_free(lines1);
     lept_free(linet1);
     lept_free(linet2);
-    return 0;
+    return regTestCleanup(rp);
 }
 
 
-static l_int32
-compareResults(PIX         *pixs,
-               PIX         *pixt1,
-               PIX         *pixt2,
-               l_int32      count1,
-               l_int32      count2,
-               const char  *descr)
+static void
+CompareResults(PIX          *pixs,
+               PIX          *pix1,
+               PIX          *pix2,
+               l_int32       count1,
+               l_int32       count2,
+               const char   *descr,
+               L_REGPARAMS  *rp)
 {
-l_int32  ret, same;
-
-    ret = 0;
-    pixEqual(pixs, pixt1, &same);
-    if (!same) {
-        fprintf(stderr, "pixt1 != pixs in %s\n", descr);
-        ret = 1;
-    }
-    pixEqual(pixs, pixt2, &same);
-    if (!same) {
-        fprintf(stderr, "pixt2 != pixs in %s\n", descr);
-        ret = 1;
-    }
-    if (count1 != count2) {
-        fprintf(stderr, "Counts not same in %s\n", descr);
-        ret = 1;
-    } else
-        fprintf(stderr, "Counts equal in %s: %d\n", descr, count1);
-    pixClearAll(pixt1);
-    pixClearAll(pixt2);
-    if (!ret)
-        fprintf(stderr, "All OK for %s\n", descr);
-    return ret;
+    fprintf(stderr, "Compare set: %s; index starts at %d\n",
+            descr, rp->index + 1);
+    regTestComparePix(rp, pixs, pix1);
+    regTestComparePix(rp, pixs, pix2);
+    regTestCompareValues(rp, count1, count2, 1);
+    pixClearAll(pix1);
+    pixClearAll(pix2);
 }
 
