@@ -38,31 +38,27 @@
 #include <math.h>
 #include "allheaders.h"
 
-#define   DO_ALL     1
-
-
 int main(int    argc,
          char **argv)
 {
 l_int32      i, n, binsize, binstart, nbins;
-l_float32    pi, val, angle, xval, yval, x0, y0, rank, startval, fbinsize;
-l_float32    minval, maxval, meanval, median, variance, rankval;
+l_float32    pi, val, angle, xval, yval, x0, y0, startval, fbinsize;
+l_float32    minval, maxval, meanval, median, variance, rankval, rank, rmsdev;
 GPLOT       *gplot;
 NUMA        *na, *nahisto, *nax, *nay, *nap, *nasx, *nasy;
 NUMA        *nadx, *nady, *nafx, *nafy, *na1, *na2, *na3, *na4;
 PIX         *pixs, *pix1, *pix2, *pix3, *pix4, *pix5, *pix6, *pix7, *pixd;
 PIXA        *pixa;
-static char  mainName[] = "numa1_reg";
+L_REGPARAMS  *rp;
 
-    if (argc != 1)
-        return ERROR_INT(" Syntax:  numa1_reg", mainName, 1);
+    if (regTestSetup(argc, argv, &rp))
+        return 1;
 
     lept_mkdir("lept/numa1");
 
     /* -------------------------------------------------------------------*
      *                            Histograms                              *
      * -------------------------------------------------------------------*/
-#if  DO_ALL
     pi = 3.1415926535;
     na = numaCreate(5000);
     for (i = 0; i < 500000; i++) {
@@ -117,48 +113,59 @@ static char  mainName[] = "numa1_reg";
     gplotAddPlot(gplot, nax, nahisto, GPLOT_LINES, "sine");
     gplotMakeOutput(gplot);
     gplotDestroy(&gplot);
-    pixa = pixaCreate(4);
     pix1 = pixRead("/tmp/lept/numa1/histo1.png");
     pix2 = pixRead("/tmp/lept/numa1/histo2.png");
     pix3 = pixRead("/tmp/lept/numa1/histo3.png");
     pix4 = pixRead("/tmp/lept/numa1/histo4.png");
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 0 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 1 */
+    regTestWritePixAndCheck(rp, pix3, IFF_PNG);  /* 2 */
+    regTestWritePixAndCheck(rp, pix4, IFF_PNG);  /* 3 */
+    pixa = pixaCreate(4);
     pixaAddPix(pixa, pix1, L_INSERT);
     pixaAddPix(pixa, pix2, L_INSERT);
     pixaAddPix(pixa, pix3, L_INSERT);
     pixaAddPix(pixa, pix4, L_INSERT);
-    pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
-    pixDisplay(pixd, 600, 0);
-    pixWrite("/tmp/lept/numa1/histo.png", pixd, IFF_PNG);
-    pixDestroy(&pixd);
+    if (rp->display) {
+        pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
+        pixDisplayWithTitle(pixd, 0, 0, NULL, 1);
+        pixDestroy(&pixd);
+    }
     pixaDestroy(&pixa);
     numaDestroy(&nax);
     numaDestroy(&nahisto);
 
     numaGetStatsUsingHistogram(na, 2000, &minval, &maxval, &meanval,
                                &variance, &median, 0.80, &rankval, &nahisto);
-    fprintf(stderr, "Sin histogram: \n"
-                    "  min val  = %7.2f    -- should be -999.00\n"
-                    "  max val  = %7.2f    -- should be  999.00\n"
-                    "  mean val = %7.2f    -- should be    0.06\n"
-                    "  median   = %7.2f    -- should be    0.30\n"
-                    "  rmsdev   = %7.2f    -- should be  706.41\n"
-                    "  rank val = %7.2f    -- should be  808.15\n",
-            minval, maxval, meanval, median, sqrt((l_float64)variance),
-            rankval);
-    numaHistogramGetRankFromVal(nahisto, 808.15, &rank);
-    fprintf(stderr, "  rank     = %7.3f    -- should be  0.800\n", rank);
+    rmsdev = sqrt((l_float64)variance);
+    numaHistogramGetRankFromVal(nahisto, rankval, &rank);
+    regTestCompareValues(rp, -999.00, minval,  0.1);    /* 4 */
+    regTestCompareValues(rp,  999.00, maxval,  0.1);    /* 5 */
+    regTestCompareValues(rp,  0.055,  meanval, 0.001);  /* 6 */
+    regTestCompareValues(rp,  0.30,   median,  0.005);  /* 7 */
+    regTestCompareValues(rp,  706.41, rmsdev,  0.1);    /* 8 */
+    regTestCompareValues(rp,  808.15, rankval, 0.1);    /* 9 */
+    regTestCompareValues(rp,  0.800,  rank,    0.01);   /* 10 */
+    if (rp->display) {
+        fprintf(stderr, "Sin histogram: \n"
+                  "  min val  = %7.3f    -- should be -999.00\n"
+                  "  max val  = %7.3f    -- should be  999.00\n"
+                  "  mean val = %7.3f    -- should be    0.055\n"
+                  "  median   = %7.3f    -- should be    0.30\n"
+                  "  rmsdev   = %7.3f    -- should be  706.41\n"
+                  "  rank val = %7.3f    -- should be  808.152\n"
+                  "  rank     = %7.3f    -- should be    0.800\n",
+                minval, maxval, meanval, median, rmsdev, rankval, rank);
+    }
     numaDestroy(&nahisto);
     numaDestroy(&na);
-#endif
 
     /* -------------------------------------------------------------------*
      *                            Interpolation                           *
      * -------------------------------------------------------------------*/
-#if  DO_ALL
         /* Test numaInterpolateEqxInterval() */
     pixs = pixRead("test8.jpg");
     na = pixGetGrayHistogramMasked(pixs, NULL, 0, 0, 1);
-/*    numaWriteStream(stderr, na); */
     nasy = numaGetPartialSums(na);
     gplotSimple1(nasy, GPLOT_PNG, "/tmp/lept/numa1/int1", "partial sums");
     gplotSimple1(na, GPLOT_PNG, "/tmp/lept/numa1/int2", "simple test");
@@ -174,16 +181,13 @@ static char  mainName[] = "numa1_reg";
     numaDestroy(&nax);
     numaDestroy(&nay);
     pixDestroy(&pixs);
-#endif
 
-#if  DO_ALL
         /* Test numaInterpolateArbxInterval() */
     pixs = pixRead("test8.jpg");
     na = pixGetGrayHistogramMasked(pixs, NULL, 0, 0, 1);
     nasy = numaGetPartialSums(na);
     numaInsertNumber(nasy, 0, 0.0);
     nasx = numaMakeSequence(0.0, 1.0, 257);
-/*    gplotSimple1(nasy, GPLOT_PNG, "/tmp/numa/nasy", "partial sums"); */
     numaInterpolateArbxInterval(nasx, nasy, L_LINEAR_INTERP,
                                 10.0, 250.0, 23, &nax, &nay);
     gplot = gplotCreate("/tmp/lept/numa1/int4", GPLOT_PNG, "arbx interpolation",
@@ -197,16 +201,13 @@ static char  mainName[] = "numa1_reg";
     numaDestroy(&nax);
     numaDestroy(&nay);
     pixDestroy(&pixs);
-#endif
 
-#if  DO_ALL
         /* Test numaInterpolateArbxVal() */
     pixs = pixRead("test8.jpg");
     na = pixGetGrayHistogramMasked(pixs, NULL, 0, 0, 1);
     nasy = numaGetPartialSums(na);
     numaInsertNumber(nasy, 0, 0.0);
     nasx = numaMakeSequence(0.0, 1.0, 257);
-/*    gplotSimple1(nasy, GPLOT_PNG, "/tmp/numa/nasy", "partial sums"); */
     nax = numaMakeSequence(15.0, (250.0 - 15.0) / 23.0, 24);
     n = numaGetCount(nax);
     nay = numaCreate(n);
@@ -226,9 +227,7 @@ static char  mainName[] = "numa1_reg";
     numaDestroy(&nax);
     numaDestroy(&nay);
     pixDestroy(&pixs);
-#endif
 
-#if  DO_ALL
         /* Test interpolation */
     nasx = numaRead("testangle.na");
     nasy = numaRead("testscore.na");
@@ -254,7 +253,7 @@ static char  mainName[] = "numa1_reg";
     gplotMakeOutput(gplot);
     gplotDestroy(&gplot);
     numaFitMax(nay, &yval, nax, &xval);
-    fprintf(stderr, "max = %f at loc = %f\n", yval, xval);
+    if (rp->display) fprintf(stderr, "max = %f at loc = %f\n", yval, xval);
     pixa = pixaCreate(7);
     pix1 = pixRead("/tmp/lept/numa1/int1.png");
     pix2 = pixRead("/tmp/lept/numa1/int2.png");
@@ -263,6 +262,13 @@ static char  mainName[] = "numa1_reg";
     pix5 = pixRead("/tmp/lept/numa1/int5.png");
     pix6 = pixRead("/tmp/lept/numa1/int6.png");
     pix7 = pixRead("/tmp/lept/numa1/int7.png");
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 11 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 12 */
+    regTestWritePixAndCheck(rp, pix3, IFF_PNG);  /* 13 */
+    regTestWritePixAndCheck(rp, pix4, IFF_PNG);  /* 14 */
+    regTestWritePixAndCheck(rp, pix5, IFF_PNG);  /* 15 */
+    regTestWritePixAndCheck(rp, pix6, IFF_PNG);  /* 16 */
+    regTestWritePixAndCheck(rp, pix7, IFF_PNG);  /* 17 */
     pixaAddPix(pixa, pix1, L_INSERT);
     pixaAddPix(pixa, pix2, L_INSERT);
     pixaAddPix(pixa, pix3, L_INSERT);
@@ -270,21 +276,20 @@ static char  mainName[] = "numa1_reg";
     pixaAddPix(pixa, pix5, L_INSERT);
     pixaAddPix(pixa, pix6, L_INSERT);
     pixaAddPix(pixa, pix7, L_INSERT);
-    pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
-    pixDisplay(pixd, 100, 900);
-    pixWrite("/tmp/lept/numa1/int.png", pixd, IFF_PNG);
-    pixDestroy(&pixd);
+    if (rp->display) {
+        pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
+        pixDisplayWithTitle(pixd, 300, 0, NULL, 1);
+        pixDestroy(&pixd);
+    }
     pixaDestroy(&pixa);
     numaDestroy(&nasx);
     numaDestroy(&nasy);
     numaDestroy(&nax);
     numaDestroy(&nay);
-#endif
 
     /* -------------------------------------------------------------------*
      *                   Integration and differentiation                  *
      * -------------------------------------------------------------------*/
-#if  DO_ALL
         /* Test integration and differentiation */
     nasx = numaRead("testangle.na");
     nasy = numaRead("testscore.na");
@@ -322,12 +327,15 @@ static char  mainName[] = "numa1_reg";
     pixa = pixaCreate(2);
     pix1 = pixRead("/tmp/lept/numa1/diff1.png");
     pix2 = pixRead("/tmp/lept/numa1/diff2.png");
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 18 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 19 */
     pixaAddPix(pixa, pix1, L_INSERT);
     pixaAddPix(pixa, pix2, L_INSERT);
-    pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
-    pixDisplay(pixd, 100, 450);
-    pixWrite("/tmp/lept/numa1/diff.png", pixd, IFF_PNG);
-    pixDestroy(&pixd);
+    if (rp->display) {
+        pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
+        pixDisplayWithTitle(pixd, 600, 0, NULL, 1);
+        pixDestroy(&pixd);
+    }
     pixaDestroy(&pixa);
     numaDestroy(&nasx);
     numaDestroy(&nasy);
@@ -336,12 +344,10 @@ static char  mainName[] = "numa1_reg";
     numaDestroy(&nadx);
     numaDestroy(&nady);
     numaDestroy(&nay);
-#endif
 
     /* -------------------------------------------------------------------*
      *                             Rank extraction                        *
      * -------------------------------------------------------------------*/
-#if  DO_ALL
         /* Rank extraction with interpolation */
     pixs = pixRead("test8.jpg");
     nasy= pixGetGrayHistogramMasked(pixs, NULL, 0, 0, 1);
@@ -355,9 +361,7 @@ static char  mainName[] = "numa1_reg";
     numaDestroy(&nax);
     numaDestroy(&nay);
     pixDestroy(&pixs);
-#endif
 
-#if  DO_ALL
         /* Rank extraction, point by point */
     pixs = pixRead("test8.jpg");
     nap = numaCreate(200);
@@ -371,22 +375,23 @@ static char  mainName[] = "numa1_reg";
     pixa = pixaCreate(2);
     pix1 = pixRead("/tmp/lept/numa1/rank1.png");
     pix2 = pixRead("/tmp/lept/numa1/rank2.png");
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 20 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 21 */
     pixaAddPix(pixa, pix1, L_INSERT);
     pixaAddPix(pixa, pix2, L_INSERT);
-    pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
-    pixDisplay(pixd, 100, 0);
-    pixWrite("/tmp/lept/numa1/rank.png", pixd, IFF_PNG);
-    pixDestroy(&pixd);
+    if (rp->display) {
+        pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
+        pixDisplayWithTitle(pixd, 900, 0, NULL, 1);
+        pixDestroy(&pixd);
+    }
     pixaDestroy(&pixa);
     numaDestroy(&na);
     numaDestroy(&nap);
     pixDestroy(&pixs);
-#endif
 
     /* -------------------------------------------------------------------*
      *                           Numa-morphology                          *
      * -------------------------------------------------------------------*/
-#if  DO_ALL
     na = numaRead("lyra.5.na");
     gplotSimple1(na, GPLOT_PNG, "/tmp/lept/numa1/lyra1", "Original");
     na1 = numaErode(na, 21);
@@ -408,10 +413,16 @@ static char  mainName[] = "numa1_reg";
     pixaAddPix(pixa, pix3, L_INSERT);
     pixaAddPix(pixa, pix4, L_INSERT);
     pixaAddPix(pixa, pix5, L_INSERT);
-    pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
-    pixDisplay(pixd, 600, 450);
-    pixWrite("/tmp/lept/numa1/morph.png", pixd, IFF_PNG);
-    pixDestroy(&pixd);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 22 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 23 */
+    regTestWritePixAndCheck(rp, pix3, IFF_PNG);  /* 24 */
+    regTestWritePixAndCheck(rp, pix4, IFF_PNG);  /* 25 */
+    regTestWritePixAndCheck(rp, pix5, IFF_PNG);  /* 26 */
+    if (rp->display) {
+        pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
+        pixDisplayWithTitle(pixd, 1200, 0, NULL, 1);
+        pixDestroy(&pixd);
+    }
     pixaDestroy(&pixa);
     numaDestroy(&na);
     numaDestroy(&na1);
@@ -419,7 +430,6 @@ static char  mainName[] = "numa1_reg";
     numaDestroy(&na3);
     numaDestroy(&na4);
     pixaDestroy(&pixa);
-#endif
 
-    return 0;
+    return regTestCleanup(rp);
 }
