@@ -41,7 +41,7 @@
 #endif  /* _WIN32 */
 #include "allheaders.h"
 
-#define   DO_ALL     1
+#define   DO_ALL     0
 
 
 int main(int    argc,
@@ -57,52 +57,54 @@ BOX         *box1, *box2;
 NUMA        *na, *na1, *na2, *na3, *na4;
 PIX         *pix, *pixs, *pix1, *pix2, *pix3, *pix4, *pix5, *pixg, *pixd;
 PIXA        *pixa;
-static char  mainName[] = "numa2_reg";
+L_REGPARAMS  *rp;
 
-    if (argc != 1)
-        return ERROR_INT(" Syntax:  numa2_reg", mainName, 1);
+    if (regTestSetup(argc, argv, &rp))
+        return 1;
 
-    setLeptDebugOK(1);
     lept_mkdir("lept/numa2");
 
     /* -------------------------------------------------------------------*
      *                         Numa-windowed stats                        *
      * -------------------------------------------------------------------*/
-#if  DO_ALL
     na = numaRead("lyra.5.na");
     numaWindowedStats(na, 5, &na1, &na2, &na3, &na4);
-    gplotSimple1(na, GPLOT_PNG, "/tmp/lept/numa2/lyra6", "Original");
-    gplotSimple1(na1, GPLOT_PNG, "/tmp/lept/numa2/lyra7", "Mean");
-    gplotSimple1(na2, GPLOT_PNG, "/tmp/lept/numa2/lyra8", "Mean Square");
-    gplotSimple1(na3, GPLOT_PNG, "/tmp/lept/numa2/lyra9", "Variance");
-    gplotSimple1(na4, GPLOT_PNG, "/tmp/lept/numa2/lyra10", "RMS Difference");
+    gplotSimple1(na, GPLOT_PNG, "/tmp/lept/numa2/lyra1", "Original");
+    gplotSimple1(na1, GPLOT_PNG, "/tmp/lept/numa2/lyra2", "Mean");
+    gplotSimple1(na2, GPLOT_PNG, "/tmp/lept/numa2/lyra3", "Mean Square");
+    gplotSimple1(na3, GPLOT_PNG, "/tmp/lept/numa2/lyra4", "Variance");
+    gplotSimple1(na4, GPLOT_PNG, "/tmp/lept/numa2/lyra5", "RMS Difference");
+    pix1 = pixRead("/tmp/lept/numa2/lyra1.png");
+    pix2 = pixRead("/tmp/lept/numa2/lyra2.png");
+    pix3 = pixRead("/tmp/lept/numa2/lyra3.png");
+    pix4 = pixRead("/tmp/lept/numa2/lyra4.png");
+    pix5 = pixRead("/tmp/lept/numa2/lyra5.png");
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 0 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 1 */
+    regTestWritePixAndCheck(rp, pix3, IFF_PNG);  /* 2 */
+    regTestWritePixAndCheck(rp, pix4, IFF_PNG);  /* 3 */
+    regTestWritePixAndCheck(rp, pix5, IFF_PNG);  /* 4 */
     pixa = pixaCreate(5);
-    pix1 = pixRead("/tmp/lept/numa2/lyra6.png");
-    pix2 = pixRead("/tmp/lept/numa2/lyra7.png");
-    pix3 = pixRead("/tmp/lept/numa2/lyra8.png");
-    pix4 = pixRead("/tmp/lept/numa2/lyra9.png");
-    pix5 = pixRead("/tmp/lept/numa2/lyra10.png");
     pixaAddPix(pixa, pix1, L_INSERT);
     pixaAddPix(pixa, pix2, L_INSERT);
     pixaAddPix(pixa, pix3, L_INSERT);
     pixaAddPix(pixa, pix4, L_INSERT);
     pixaAddPix(pixa, pix5, L_INSERT);
-    pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
-    pixDisplay(pixd, 100, 0);
-    pixWrite("/tmp/lept/numa2/window.png", pixd, IFF_PNG);
-    pixDestroy(&pixd);
+    if (rp->display) {
+        pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
+        pixDisplayWithTitle(pixd, 0, 0, NULL, 1);
+        pixDestroy(&pixd);
+    }
     pixaDestroy(&pixa);
     numaDestroy(&na);
     numaDestroy(&na1);
     numaDestroy(&na2);
     numaDestroy(&na3);
     numaDestroy(&na4);
-#endif
 
     /* -------------------------------------------------------------------*
      *                        Extraction on a line                        *
      * -------------------------------------------------------------------*/
-#if  DO_ALL
         /* First, make a pretty image */
     w = h = 200;
     pixs = pixCreate(w, h, 32);
@@ -119,8 +121,8 @@ static char  mainName[] = "numa2_reg";
         }
     }
     pixg = pixConvertTo8(pixs, 0);  /* and a grayscale version */
-    pixWrite("/tmp/lept/numa_pixg.png", pixg, IFF_PNG);
-    pixDisplay(pixg, 450, 100);
+    regTestWritePixAndCheck(rp, pixg, IFF_PNG);  /* 5 */
+    pixDisplayWithTitle(pixg, 0, 300, NULL, rp->display);
 
     na1 = pixExtractOnLine(pixg, 20, 20, 180, 20, 1);
     na2 = pixExtractOnLine(pixg, 40, 30, 40, 170, 1);
@@ -132,31 +134,35 @@ static char  mainName[] = "numa2_reg";
                 "Slightly more horizontal than vertical");
     gplotSimple1(na4, GPLOT_PNG, "/tmp/lept/numa2/ext4",
                 "Slightly more vertical than horizontal");
-    pixa = pixaCreate(4);
     pix1 = pixRead("/tmp/lept/numa2/ext1.png");
     pix2 = pixRead("/tmp/lept/numa2/ext2.png");
     pix3 = pixRead("/tmp/lept/numa2/ext3.png");
     pix4 = pixRead("/tmp/lept/numa2/ext4.png");
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 6 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 7 */
+    regTestWritePixAndCheck(rp, pix3, IFF_PNG);  /* 8 */
+    regTestWritePixAndCheck(rp, pix4, IFF_PNG);  /* 9 */
+    pixa = pixaCreate(4);
     pixaAddPix(pixa, pix1, L_INSERT);
     pixaAddPix(pixa, pix2, L_INSERT);
     pixaAddPix(pixa, pix3, L_INSERT);
     pixaAddPix(pixa, pix4, L_INSERT);
-    pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
-    pixDisplay(pixd, 100, 450);
-    pixWrite("/tmp/lept/numa2/extract.png", pixd, IFF_PNG);
-    pixDestroy(&pixd);
+    if (rp->display) {
+        pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
+        pixDisplayWithTitle(pixd, 300, 0, NULL, 1);
+        pixDestroy(&pixd);
+    }
     pixaDestroy(&pixa);
     pixDestroy(&pixg);
+    pixDestroy(&pixs);
     numaDestroy(&na1);
     numaDestroy(&na2);
     numaDestroy(&na3);
     numaDestroy(&na4);
-#endif
 
     /* -------------------------------------------------------------------*
      *                     Row and column pixel sums                      *
      * -------------------------------------------------------------------*/
-#if  DO_ALL
         /* Sum by columns in two halves (left and right) */
     pixs = pixRead("test8.jpg");
     pixGetDimensions(pixs, &w, &h, NULL);
@@ -166,15 +172,12 @@ static char  mainName[] = "numa2_reg";
     na2 = pixAverageByColumn(pixs, box2, L_BLACK_IS_MAX);
     numaJoin(na1, na2, 0, -1);
     na3 = pixAverageByColumn(pixs, NULL, L_BLACK_IS_MAX);
-    numaSimilar(na1, na3, 0.0, &same);
-    if (same)
-        fprintf(stderr, "Same for columns\n");
-    else
-        fprintf(stderr, "Error for columns\n");
-    pix = pixConvertTo32(pixs);
-    pixRenderPlotFromNumaGen(&pix, na3, L_HORIZONTAL_LINE, 3, h / 2, 80, 1,
+    numaSimilar(na1, na3, 0.0, &same);  /* for columns */
+    regTestCompareValues(rp, 1, same, 0);  /* 10 */
+    pix1 = pixConvertTo32(pixs);
+    pixRenderPlotFromNumaGen(&pix1, na3, L_HORIZONTAL_LINE, 3, h / 2, 80, 1,
                              0xff000000);
-    pixRenderPlotFromNuma(&pix, na3, L_PLOT_AT_BOT, 3, 80, 0xff000000);
+    pixRenderPlotFromNuma(&pix1, na3, L_PLOT_AT_BOT, 3, 80, 0xff000000);
     boxDestroy(&box1);
     boxDestroy(&box2);
     numaDestroy(&na1);
@@ -188,21 +191,19 @@ static char  mainName[] = "numa2_reg";
     na2 = pixAverageByRow(pixs, box2, L_WHITE_IS_MAX);
     numaJoin(na1, na2, 0, -1);
     na3 = pixAverageByRow(pixs, NULL, L_WHITE_IS_MAX);
-    numaSimilar(na1, na3, 0.0, &same);
-    if (same)
-        fprintf(stderr, "Same for rows\n");
-    else
-        fprintf(stderr, "Error for rows\n");
-    pixRenderPlotFromNumaGen(&pix, na3, L_VERTICAL_LINE, 3, w / 2, 80, 1,
+    numaSimilar(na1, na3, 0.0, &same);  /* for rows */
+    regTestCompareValues(rp, 1, same, 0);  /* 11 */
+    pixRenderPlotFromNumaGen(&pix1, na3, L_VERTICAL_LINE, 3, w / 2, 80, 1,
                              0x00ff0000);
-    pixRenderPlotFromNuma(&pix, na3, L_PLOT_AT_RIGHT, 3, 80, 0x00ff0000);
-    pixDisplay(pix, 500, 200);
+    pixRenderPlotFromNuma(&pix1, na3, L_PLOT_AT_RIGHT, 3, 80, 0x00ff0000);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 12 */
+    pixDisplayWithTitle(pix1, 0, 600, NULL, rp->display);
+    pixDestroy(&pix1);
     boxDestroy(&box1);
     boxDestroy(&box2);
     numaDestroy(&na1);
     numaDestroy(&na2);
     numaDestroy(&na3);
-    pixDestroy(&pix);
 
         /* Average left by rows; right by columns; compare totals */
     box1 = boxCreate(0, 0, w / 2, h);
@@ -214,62 +215,65 @@ static char  mainName[] = "numa2_reg";
     ave1 = sum1 / h;
     ave2 = 2.0 * sum2 / w;
     ave3 = 0.5 * (ave1 + ave2);  /* average over both halves */
-    fprintf(stderr, "ave1 = %8.4f\n", sum1 / h);
-    fprintf(stderr, "ave2 = %8.4f\n", 2.0 * sum2 / w);
+    regTestCompareValues(rp, 189.59, ave1, 0.01);  /* 13 */
+    regTestCompareValues(rp, 207.89, ave2, 0.01);  /* 14 */
+
+    if (rp->display) {
+        fprintf(stderr, "ave1 = %8.4f\n", sum1 / h);
+        fprintf(stderr, "ave2 = %8.4f\n", 2.0 * sum2 / w);
+    }
     pixAverageInRect(pixs, NULL, &ave4);  /* entire image */
     diff1 = ave4 - ave3;
     diff2 = w * h * ave4 - (0.5 * w * sum1 + h * sum2);
-    if (diff1 < 0.001)
-        fprintf(stderr, "Average diffs are correct\n");
-    else
-        fprintf(stderr, "Average diffs are wrong: diff1 = %7.5f\n", diff1);
-    if (diff2 < 20)  /* float-to-integer roundoff */
-        fprintf(stderr, "Pixel sums are correct\n");
-    else
-        fprintf(stderr, "Pixel sums are in error: diff = %7.0f\n", diff2);
+    regTestCompareValues(rp, 0.0, diff1, 0.001);  /* 15 */
+    regTestCompareValues(rp, 10.0, diff2, 10.0);  /* 16 */
 
         /* Variance left and right halves.  Variance doesn't average
          * in a simple way, unlike pixel sums. */
     pixVarianceInRect(pixs, box1, &var1);  /* entire image */
     pixVarianceInRect(pixs, box2, &var2);  /* entire image */
     pixVarianceInRect(pixs, NULL, &var3);  /* entire image */
-    fprintf(stderr, "0.5 * (var1 + var2) = %7.3f, var3 = %7.3f\n",
-            0.5 * (var1 + var2), var3);
+    regTestCompareValues(rp, 82.06, 0.5 * (var1 + var2), 0.01);  /* 17 */
+    regTestCompareValues(rp, 82.66, var3, 0.01);  /* 18 */
     boxDestroy(&box1);
     boxDestroy(&box2);
     numaDestroy(&na1);
     numaDestroy(&na2);
-#endif
 
     /* -------------------------------------------------------------------*
      *                     Row and column variances                       *
      * -------------------------------------------------------------------*/
-#if  DO_ALL
-
         /* Display variance by rows and columns */
     box1 = boxCreate(415, 0, 130, 425);
     boxGetGeometry(box1, NULL, NULL, &bw, &bh);
     na1 = pixVarianceByRow(pixs, box1);
     na2 = pixVarianceByColumn(pixs, box1);
-    pix = pixConvertTo32(pixs);
-    pix1 = pixCopy(NULL, pix);
-    pixRenderPlotFromNumaGen(&pix, na1, L_VERTICAL_LINE, 3, 415, 100, 1,
+    pix1 = pixConvertTo32(pixs);
+    pix2 = pixCopy(NULL, pix1);
+    pixRenderPlotFromNumaGen(&pix1, na1, L_VERTICAL_LINE, 3, 415, 100, 1,
                              0xff000000);
-    pixRenderPlotFromNumaGen(&pix, na2, L_HORIZONTAL_LINE, 3, bh / 2, 100, 1,
+    pixRenderPlotFromNumaGen(&pix1, na2, L_HORIZONTAL_LINE, 3, bh / 2, 100, 1,
                           0x00ff0000);
-    pixRenderPlotFromNuma(&pix1, na1, L_PLOT_AT_LEFT, 3, 60, 0x00ff0000);
-    pixRenderPlotFromNuma(&pix1, na1, L_PLOT_AT_MID_VERT, 3, 60, 0x0000ff00);
-    pixRenderPlotFromNuma(&pix1, na1, L_PLOT_AT_RIGHT, 3, 60, 0xff000000);
-    pixRenderPlotFromNuma(&pix1, na2, L_PLOT_AT_TOP, 3, 60, 0x0000ff00);
-    pixRenderPlotFromNuma(&pix1, na2, L_PLOT_AT_MID_HORIZ, 3, 60, 0xff000000);
-    pixRenderPlotFromNuma(&pix1, na2, L_PLOT_AT_BOT, 3, 60, 0x00ff0000);
-    pixDisplay(pix, 500, 900);
-    pixDisplay(pix1, 500, 1000);
+    pixRenderPlotFromNuma(&pix2, na1, L_PLOT_AT_LEFT, 3, 60, 0x00ff0000);
+    pixRenderPlotFromNuma(&pix2, na1, L_PLOT_AT_MID_VERT, 3, 60, 0x0000ff00);
+    pixRenderPlotFromNuma(&pix2, na1, L_PLOT_AT_RIGHT, 3, 60, 0xff000000);
+    pixRenderPlotFromNuma(&pix2, na2, L_PLOT_AT_TOP, 3, 60, 0x0000ff00);
+    pixRenderPlotFromNuma(&pix2, na2, L_PLOT_AT_MID_HORIZ, 3, 60, 0xff000000);
+    pixRenderPlotFromNuma(&pix2, na2, L_PLOT_AT_BOT, 3, 60, 0x00ff0000);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 19 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 20 */
+    pixa = pixaCreate(2);
+    pixaAddPix(pixa, pix1, L_INSERT);
+    pixaAddPix(pixa, pix2, L_INSERT);
+    if (rp->display) {
+        pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
+        pixDisplayWithTitle(pixd, 400, 600, NULL, 1);
+        pixDestroy(&pixd);
+    }
+    pixaDestroy(&pixa);
     boxDestroy(&box1);
     numaDestroy(&na1);
     numaDestroy(&na2);
-    pixDestroy(&pix);
-    pixDestroy(&pix1);
     pixDestroy(&pixs);
 
         /* Again on a different image */
@@ -283,34 +287,38 @@ static char  mainName[] = "numa2_reg";
     na2 = pixVarianceByColumn(pix2, NULL);
     pixRenderPlotFromNumaGen(&pix3, na2, L_HORIZONTAL_LINE, 3, bh - 1, 70, 1,
                              0x00ff0000);
-    pixDisplay(pix3, 1000, 0);
+    regTestWritePixAndCheck(rp, pix3, IFF_PNG);  /* 21 */
     numaDestroy(&na1);
     numaDestroy(&na2);
-    pixDestroy(&pix3);
 
         /* Again, with an erosion */
-    pix3 = pixErodeGray(pix2, 3, 21);
-    pixDisplay(pix3, 1400, 0);
-    na1 = pixVarianceByRow(pix3, NULL);
-    pix4 = pixConvertTo32(pix1);
-    pixRenderPlotFromNumaGen(&pix4, na1, L_VERTICAL_LINE, 3, 30, 70, 1,
+    pix4 = pixErodeGray(pix2, 3, 21);
+    na1 = pixVarianceByRow(pix4, NULL);
+    pix5 = pixConvertTo32(pix1);
+    pixRenderPlotFromNumaGen(&pix5, na1, L_VERTICAL_LINE, 3, 30, 70, 1,
                              0xff000000);
-    na2 = pixVarianceByColumn(pix3, NULL);
-    pixRenderPlotFromNumaGen(&pix4, na2, L_HORIZONTAL_LINE, 3, bh - 1, 70, 1,
+    na2 = pixVarianceByColumn(pix4, NULL);
+    pixRenderPlotFromNumaGen(&pix5, na2, L_HORIZONTAL_LINE, 3, bh - 1, 70, 1,
                              0x00ff0000);
-    pixDisplay(pix4, 1000, 550);
-    numaDestroy(&na1);
-    numaDestroy(&na2);
+    regTestWritePixAndCheck(rp, pix5, IFF_PNG);  /* 22 */
+    pixa = pixaCreate(2);
+    pixaAddPix(pixa, pix3, L_INSERT);
+    pixaAddPix(pixa, pix5, L_INSERT);
+    if (rp->display) {
+        pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
+        pixDisplayWithTitle(pixd, 800, 600, NULL, 1);
+        pixDestroy(&pixd);
+    }
+    pixaDestroy(&pixa);
     pixDestroy(&pix1);
     pixDestroy(&pix2);
-    pixDestroy(&pix3);
     pixDestroy(&pix4);
-#endif
+    numaDestroy(&na1);
+    numaDestroy(&na2);
 
     /* -------------------------------------------------------------------*
      *                    Windowed variance along a line                  *
      * -------------------------------------------------------------------*/
-#if  DO_ALL
     pix1 = pixRead("boxedpage.jpg");
     pix2 = pixConvertTo8(pix1, 0);
     pixGetDimensions(pix2, &w, &h, NULL);
@@ -331,13 +339,20 @@ static char  mainName[] = "numa2_reg";
                              1, 0x00ff0000);
     pixRenderPlotFromNuma(&pix3, na2, L_PLOT_AT_LEFT, 3, 60, 0xff000000);
     pixRenderPlotFromNuma(&pix3, na2, L_PLOT_AT_RIGHT, 3, 60, 0x00ff0000);
-    pixDisplay(pix1, 1000, 1000);
-    pixDisplay(pix3, 1500, 1000);
-    pixDestroy(&pix1);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 23 */
+    regTestWritePixAndCheck(rp, pix3, IFF_PNG);  /* 24 */
+    pixa = pixaCreate(2);
+    pixaAddPix(pixa, pix1, L_INSERT);
+    pixaAddPix(pixa, pix3, L_INSERT);
+    if (rp->display) {
+        pixd = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 20, 2);
+        pixDisplayWithTitle(pixd, 1200, 600, NULL, 1);
+        pixDestroy(&pixd);
+    }
+    pixaDestroy(&pixa);
     pixDestroy(&pix2);
-    pixDestroy(&pix3);
     numaDestroy(&na1);
     numaDestroy(&na2);
-#endif
-    return 0;
+
+    return regTestCleanup(rp);;
 }
