@@ -37,10 +37,16 @@
 int main(int    argc,
          char **argv)
 {
+l_uint8      *data;
+char         *fname;
 l_int32       i, n, istable, score;
+size_t        size;
+BOX          *box;
 BOXA         *boxa;
 PIX          *pixs, *pix1, *pix2, *pixhm, *pixtm, *pixtb, *pixdb;
 PIXA         *pixadb;
+PIXAC        *pixac;
+SARRAY       *sa;
 L_REGPARAMS  *rp;
 
     if (regTestSetup(argc, argv, &rp))
@@ -75,10 +81,41 @@ L_REGPARAMS  *rp;
     }
     pixaDestroy(&pixadb);
 
+        /* Test foreground finding */
+    sa = getSortedPathnamesInDirectory(".", "lion-page", 0, 0);
+    n = sarrayGetCount(sa);
+    boxa = boxaCreate(n);
+    box = boxCreate(0, 0, 0, 0);  /* invalid box */
+    boxaInitFull(boxa, box);  /* Init to invalid boxes */
+    boxDestroy(&box);
+    pixac = pixacompCreate(n);
+    for (i = 0; i < n; i++) {
+        fname = sarrayGetString(sa, i, L_NOCOPY);
+        pix1 = pixRead(fname);
+        box = pixFindPageForeground(pix1, 170, 70, 30, 0, pixac);
+        if (!box) {
+            pixDestroy(&pix1);
+            continue;
+        }
+        boxaReplaceBox(boxa, i, box);
+        pixDestroy(&pix1);
+    }
+    boxaWriteMem(&data, &size, boxa);
+    regTestWriteDataAndCheck(rp, data, size, "ba");  /* 19 */
+    boxaDestroy(&boxa);
+    lept_free(data);
+    l_pdfSetDateAndVersion(0);
+    pixacompConvertToPdfData(pixac, 0, 1.0, L_DEFAULT_ENCODE, 0,
+                             "Page foreground", &data, &size);
+    regTestWriteDataAndCheck(rp, data, size, "pdf");  /* 20 */
+    lept_free(data);
+    sarrayDestroy(&sa);
+    pixacompDestroy(&pixac);
+
         /* Test the greedy rectangle finder for white space */
     pix1 = pixScale(pixs, 0.5, 0.5);
     pixFindLargeRectangles(pix1, 0, 20, &boxa, &pixdb);
-    regTestWritePixAndCheck(rp, pixdb, IFF_PNG);  /* 19 */
+    regTestWritePixAndCheck(rp, pixdb, IFF_PNG);  /* 21 */
     pixDisplayWithTitle(pixdb, 0, 700, NULL, rp->display);
     pixDestroy(&pixs);
     pixDestroy(&pix1);
@@ -90,9 +127,9 @@ L_REGPARAMS  *rp;
     pixadb = pixaCreate(0);
     pixDecideIfTable(pix1, NULL, L_PORTRAIT_MODE, &score, pixadb);
     istable = (score >= 2) ? 1 : 0;
-    regTestCompareValues(rp, 1.0, istable, 0.0);  /* 20 */
+    regTestCompareValues(rp, 1.0, istable, 0.0);  /* 22 */
     pix2 = pixaDisplayTiledInRows(pixadb, 32, 2000, 1.0, 0, 30, 2);
-    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 21 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 23 */
     pixDisplayWithTitle(pix2, 700, 700, NULL, rp->display);
     pixDestroy(&pix1);
     pixDestroy(&pix2);
@@ -102,9 +139,9 @@ L_REGPARAMS  *rp;
     pixadb = pixaCreate(0);
     pixDecideIfTable(pix1, NULL, L_PORTRAIT_MODE, &score, pixadb);
     istable = (score >= 2) ? 1 : 0;
-    regTestCompareValues(rp, 1.0, istable, 0.0);  /* 22 */
+    regTestCompareValues(rp, 1.0, istable, 0.0);  /* 24 */
     pix2 = pixaDisplayTiledInRows(pixadb, 32, 2000, 1.0, 0, 30, 2);
-    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 23 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 25 */
     pixDisplayWithTitle(pix2, 1000, 700, NULL, rp->display);
     pixDestroy(&pix1);
     pixDestroy(&pix2);
@@ -114,9 +151,9 @@ L_REGPARAMS  *rp;
     pixadb = pixaCreate(0);
     pixDecideIfTable(pix1, NULL, L_PORTRAIT_MODE, &score, pixadb);
     istable = (score >= 2) ? 1 : 0;
-    regTestCompareValues(rp, 1.0, istable, 0.0);  /* 24 */
+    regTestCompareValues(rp, 1.0, istable, 0.0);  /* 26 */
     pix2 = pixaDisplayTiledInRows(pixadb, 32, 2000, 1.0, 0, 30, 2);
-    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 25 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 27 */
     pixDisplayWithTitle(pix2, 1300, 700, NULL, rp->display);
     pixDestroy(&pix1);
     pixDestroy(&pix2);
@@ -126,9 +163,9 @@ L_REGPARAMS  *rp;
     pixadb = pixaCreate(0);
     pixDecideIfTable(pix1, NULL, L_PORTRAIT_MODE, &score, pixadb);
     istable = (score >= 2) ? 1 : 0;
-    regTestCompareValues(rp, 0.0, istable, 0.0);  /* 26 */
+    regTestCompareValues(rp, 0.0, istable, 0.0);  /* 28 */
     pix2 = pixaDisplayTiledInRows(pixadb, 32, 2000, 1.0, 0, 30, 2);
-    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 27 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 29 */
     pixDisplayWithTitle(pix2, 1600, 700, NULL, rp->display);
     pixDestroy(&pix1);
     pixDestroy(&pix2);
