@@ -31,55 +31,69 @@
  *   as necessary, to get a maximum filling when printing onto an
  *   8.5 x 11 inch page.
  *
- *        Syntax:  printimage <filein> <printer> [other lpr args]
+ *        Syntax:  printimage <filein> [printer, other lpr args]
  *
- *   The most simple input would be something like this:
+ *   The simplest input would be something like
+ *        printimage myfile.jpg
+ *   This generates the PostScript file /tmp/print_image.ps, but
+ *   does not send it to a printer.
+ *
+ *   If you have lpr, you can specify a printer; e.g.
  *        printimage myfile.jpg myprinter
  *
- *   You can add lpr flags after this.
- *   To print more than one copy, add:
+ *   You can add lpr flags.  Two useful ones are:
+ *   * to print more than one copy
  *       -#N        (prints N copies)
- *   To print in color, add a printer-dependent flag; e.g.,
- *       -o ColorModel=Color
+ *   * to print in color (flag is printer-dependent)
+ *       -o ColorModel=Color    or
  *       -o ColorModel=CMYK
  *
  *   For example, to make 3 color copies, you might use:
  *       printimage myfile.jpg myprinter -#3 -o ColorModel=Color
  *
- *   The intermediate PostScript file generated is level 1 (uncompressed).
- *   This can be large, but it will work on all PostScript printers.
+ *   By default, the intermediate PostScript file generated is
+ *   level 3 (compressed):
+ *       /tmp/print_image.ps
+ *
+ *   If your system does not have lpr, it likely has lp.  You can run
+ *   printimage to make the PostScript file, and then print with lp:
+ *       lp -d <printer> /tmp/print_image.ps
+ *       lp -d <printer> -o ColorModel=Color /tmp/print_image.ps
+ *   etc.
  *
  *   ***************************************************************
- *   N.B.  This requires lpr, which is invoked via 'system'.  It could
- *         pose a security vulnerability if used as a service in a
- *         production environment.  Consequently, this program should
- *         only be used for debug and testing.
+ *   N.B.  If a printer is specified, this program invokes lpr via
+ *         "system'.  It could pose a security vulnerability if used
+ *         as a service in a production environment.  Consequently,
+ *         this program should only be used for debug and testing.
  *   ***************************************************************
  */
 
 #include "allheaders.h"
 
-static const l_float32  FILL_FACTOR = 0.95;   /* fill factor on 8.5 x 11 page */
+#define  USE_COMPRESSED    1
 
+static const l_float32  FILL_FACTOR = 0.95;   /* fill factor on 8.5 x 11 page */
 
 int main(int    argc,
          char **argv)
 {
 char        *filein, *printer, *extra, *fname;
 char         buffer[512];
-l_int32      i, w, h, ignore;
+l_int32      i, w, h, ret, index;
 l_float32    scale;
 FILE        *fp;
 PIX         *pixs, *pix1;
 SARRAY      *sa;
 static char  mainName[] = "printimage";
 
-    if (argc < 3)
+    if (argc < 2)
         return ERROR_INT(
-            " Syntax:  printimage <filein> <printer> [other lpr args]",
+            " Syntax:  printimage <filein> [printer, other lpr args]",
             mainName, 1);
     filein = argv[1];
-    printer = argv[2];
+    if (argc > 2)
+        printer = argv[2];
 
     fprintf(stderr,
          "\n!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n"
@@ -89,7 +103,7 @@ static char  mainName[] = "printimage";
          "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n\n");
 
     setLeptDebugOK(1);
-    lept_rm(NULL, "print_image.ps");
+    (void)lept_rm(NULL, "print_image.ps");
 
     if ((pixs = pixRead(filein)) == NULL)
         return ERROR_INT("pixs not made", mainName, 1);
@@ -104,32 +118,38 @@ static char  mainName[] = "printimage";
     }
     scale = L_MIN(FILL_FACTOR * 2550 / w, FILL_FACTOR * 3300 / h);
     fname = genPathname("/tmp", "print_image.ps");
+#if USE_COMPRESSED
+    index = 0;
+    pixWriteCompressedToPS(pix1, fname, (l_int32)(300. / scale), 3, &index);
+#else  /* uncompressed, level 1 */
     fp = lept_fopen(fname, "wb+");
     pixWriteStreamPS(fp, pix1, NULL, 300, scale);
     lept_fclose(fp);
+#endif  /* USE_COMPRESSED */
 
-        /* Print it out */
-    extra = NULL;
-    if (argc > 3) {  /* concatenate the extra args */
-        sa = sarrayCreate(0);
-        for (i = 3; i < argc; i++)
-            sarrayAddString(sa, argv[i], L_COPY);
-        extra = sarrayToString(sa, 2);
-        sarrayDestroy(&sa);
-    }
-    if (!extra) {
-        snprintf(buffer, sizeof(buffer), "lpr %s -P%s &", fname, printer);
-        ignore = system(buffer);
-    } else {
-        snprintf(buffer, sizeof(buffer), "lpr %s -P%s %s &",
-                 fname, printer, extra);
-        ignore = system(buffer);
+        /* Optionally print it out */
+    if (argc > 2) {
+        extra = NULL;
+        if (argc > 3) {  /* concatenate the extra args */
+            sa = sarrayCreate(0);
+            for (i = 3; i < argc; i++)
+                sarrayAddString(sa, argv[i], L_COPY);
+            extra = sarrayToString(sa, 2);
+            sarrayDestroy(&sa);
+        }
+        if (!extra) {
+            snprintf(buffer, sizeof(buffer), "lpr %s -P%s &", fname, printer);
+            ret = system(buffer);
+        } else {
+            snprintf(buffer, sizeof(buffer), "lpr %s -P%s %s &",
+                     fname, printer, extra);
+            ret = system(buffer);
+        }
+        lept_free(extra);
     }
 
     lept_free(fname);
-    lept_free(extra);
     pixDestroy(&pixs);
     pixDestroy(&pix1);
     return 0;
 }
-
