@@ -24,7 +24,6 @@
  -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *====================================================================*/
 
-
 /*
  * wordboxes_reg.c
  *
@@ -41,17 +40,21 @@ void MakeWordBoxes2(PIX *pixs, l_float32 scalefact, l_int32 thresh,
                     L_REGPARAMS  *rp);
 void TestBoxaAdjacency(PIX *pixs, L_REGPARAMS  *rp);
 
+#define  DO_ALL   1
 
 int main(int    argc,
          char **argv)
 {
-PIX          *pix1;
+BOX          *box1, *box2;
+BOXA         *boxa1;
+BOXAA        *boxaa1;
+PIX          *pix1, *pix2, *pix3, *pix4;
 L_REGPARAMS  *rp;
 
     if (regTestSetup(argc, argv, &rp))
         return 1;
 
-#if 1
+#if DO_ALL
         /* Make word boxes using pixWordMaskByDilation() */
     pix1 = pixRead("lucasta.150.jpg");
     MakeWordBoxes1(pix1, 1.0, 140, 0, rp);  /* 0 */
@@ -59,49 +62,73 @@ L_REGPARAMS  *rp;
     pixDestroy(&pix1);
 #endif
 
-#if 1
+#if DO_ALL
     pix1 = pixRead("zanotti-78.jpg");
     MakeWordBoxes1(pix1, 1.0, 140, 2, rp);  /* 2 */
     MakeWordBoxes1(pix1, 0.6, 140, 3, rp);  /* 3 */
     pixDestroy(&pix1);
 #endif
 
-#if 1
+#if DO_ALL
     pix1 = pixRead("words.15.tif");
     MakeWordBoxes1(pix1, 1.0, 140, 4, rp);  /* 4 */
     MakeWordBoxes1(pix1, 0.6, 140, 5, rp);  /* 5 */
     pixDestroy(&pix1);
 #endif
 
-#if 1
+#if DO_ALL
     pix1 = pixRead("words.44.tif");
     MakeWordBoxes1(pix1, 1.0, 140, 6, rp);  /* 6 */
     MakeWordBoxes1(pix1, 0.6, 140, 7, rp);  /* 7 */
     pixDestroy(&pix1);
 #endif
 
-#if 1
+#if DO_ALL
         /* Make word boxes using the higher-level functions
          * pixGetWordsInTextlines() and pixGetWordBoxesInTextlines() */
- 
+
     pix1 = pixRead("lucasta.150.jpg");
     MakeWordBoxes2(pix1, 0.7, 140, rp);  /* 8, 9 */
     pixDestroy(&pix1);
 #endif
 
-#if 1
+#if DO_ALL
     pix1 = pixRead("zanotti-78.jpg");
     MakeWordBoxes2(pix1, 0.7, 140, rp);  /* 10, 11 */
     pixDestroy(&pix1);
 #endif
 
-#if 1
+#if DO_ALL
         /* Test boxa adjacency function */
     pix1 = pixRead("lucasta.150.jpg");
     TestBoxaAdjacency(pix1, rp);  /* 12 - 15 */
     pixDestroy(&pix1);
 #endif
 
+#if DO_ALL
+        /* Test word and character box finding */
+    pix1 = pixRead("zanotti-78.jpg");
+    box1 = boxCreate(0, 0, 1500, 700);
+    pix2 = pixClipRectangle(pix1, box1, NULL);
+    box2 = boxCreate(150, 130, 1500, 355);
+    pixFindWordAndCharacterBoxes(pix2, box2, 130, &boxa1, &boxaa1,
+                                 "/tmp/lept/testboxes");
+    pix3 = pixRead("/tmp/lept/testboxes/words.png");
+    pix4 = pixRead("/tmp/lept/testboxes/chars.png");
+    regTestWritePixAndCheck(rp, pix3, IFF_PNG);  /* 16 */
+    regTestWritePixAndCheck(rp, pix4, IFF_PNG);  /* 17 */
+    pixDisplayWithTitle(pix3, 200, 1000, NULL, rp->display);
+    pixDisplayWithTitle(pix4, 200, 100, NULL, rp->display);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+    pixDestroy(&pix3);
+    pixDestroy(&pix4);
+    boxDestroy(&box1);
+    boxDestroy(&box2);
+    boxaDestroy(&boxa1);
+    boxaaDestroy(&boxaa1);
+#endif
+
     return regTestCleanup(rp);
 }
 
