@@ -61,7 +61,7 @@ static l_int32 dewarpaTestForValidModel(L_DEWARPA *dewa, L_DEWARP *dew,
                                         l_int32 notests);
 
 #ifndef  NO_CONSOLE_IO
-#define  DEBUG_INVALID_MODELS      0   /* set this to 1 for debuging */
+#define  DEBUG_INVALID_MODELS      0   /* set this to 1 for debugging */
 #endif  /* !NO_CONSOLE_IO */
 
     /* Special parameter values */
@@ -93,7 +93,7 @@ static const l_int32     GRAYIN_VALUE = 200;
  *      (4) If it can't build a model, returns a copy of pixs in &pixd.
  * </pre>
  */
-l_int32
+l_ok
 dewarpSinglePage(PIX         *pixs,
                  l_int32      thresh,
                  l_int32      adaptive,
@@ -161,7 +161,7 @@ PIX        *pixb;
  *             pixDestroy(&pixb);
  * </pre>
  */
-l_int32
+l_ok
 dewarpSinglePageInit(PIX         *pixs,
                      l_int32      thresh,
                      l_int32      adaptive,
@@ -219,7 +219,7 @@ PIX  *pix1;
  *      (4) If a model cannot be built, this returns a copy of pixs in &pixd.
  * </pre>
  */
-l_int32
+l_ok
 dewarpSinglePageRun(PIX        *pixs,
                     PIX        *pixb,
                     L_DEWARPA  *dewa,
@@ -285,7 +285,7 @@ L_DEWARP    *dew;
  *      (2) It is called by the dewarpa serializer before writing.
  * </pre>
  */
-l_int32
+l_ok
 dewarpaListPages(L_DEWARPA  *dewa)
 {
 l_int32    i;
@@ -337,7 +337,7 @@ NUMA      *namodels, *napages;
  *          dewarpaInsertRefModels().
  * </pre>
  */
-l_int32
+l_ok
 dewarpaSetValidModels(L_DEWARPA  *dewa,
                       l_int32     notests,
                       l_int32     debug)
@@ -443,7 +443,7 @@ L_DEWARP  *dew;
  *          to bring real models from the cache back to the primary array.
  * </pre>
  */
-l_int32
+l_ok
 dewarpaInsertRefModels(L_DEWARPA  *dewa,
                        l_int32     notests,
                        l_int32     debug)
@@ -574,7 +574,7 @@ NUMA      *na, *nah;
  *          These references were generated by dewarpaInsertRefModels(dewa).
  * </pre>
  */
-l_int32
+l_ok
 dewarpaStripRefModels(L_DEWARPA  *dewa)
 {
 l_int32    i;
@@ -615,7 +615,7 @@ L_DEWARP  *dew;
  *          the reference models before dewa->modelsready is true.
  * </pre>
  */
-l_int32
+l_ok
 dewarpaRestoreModels(L_DEWARPA  *dewa)
 {
 l_int32    i;
@@ -660,7 +660,7 @@ L_DEWARP  *dew;
  * \param[in]    dewa
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 dewarpaInfo(FILE       *fp,
             L_DEWARPA  *dewa)
 {
@@ -752,7 +752,7 @@ L_DEWARP  *dew;
  *          and hvalid fields.
  * </pre>
  */
-l_int32
+l_ok
 dewarpaModelStats(L_DEWARPA  *dewa,
                   l_int32    *pnnone,
                   l_int32    *pnvsuccess,
@@ -908,7 +908,7 @@ l_int32  maxcurv, diffcurv, diffedge;
  *      (2) This only shows actual models; not ref models
  * </pre>
  */
-l_int32
+l_ok
 dewarpaShowArrays(L_DEWARPA   *dewa,
                   l_float32    scalefact,
                   l_int32      first,
@@ -973,7 +973,7 @@ PIXA      *pixa;
         pixd = pixAddSingleTextblock(pixt, bmf, buf, 0x0000ff00,
                                      L_ADD_BELOW, NULL);
         snprintf(buf, sizeof(buf), "/tmp/lept/dewarp1/arrays_%04d.png", i);
-        pixWrite(buf, pixd, IFF_PNG);
+        pixWriteDebug(buf, pixd, IFF_PNG);
         pixaDestroy(&pixa);
         pixDestroy(&pixt);
         pixDestroy(&pixd);
@@ -1004,7 +1004,7 @@ PIXA      *pixa;
  *                /tmp/[subdirs]/pixv_[index].png
  * </pre>
  */
-l_int32
+l_ok
 dewarpDebug(L_DEWARP    *dew,
             const char  *subdirs,
             l_int32      index)
@@ -1056,13 +1056,13 @@ PIX     *pixv, *pixh;
     if (svd) {
         pixv = fpixRenderContours(dew->fullvdispar, 3.0, 0.15);
         snprintf(fname, sizeof(fname), "%s/pixv_%d.png", outdir, index);
-        pixWrite(fname, pixv, IFF_PNG);
+        pixWriteDebug(fname, pixv, IFF_PNG);
         pixDestroy(&pixv);
     }
     if (shd) {
         pixh = fpixRenderContours(dew->fullhdispar, 3.0, 0.15);
         snprintf(fname, sizeof(fname), "%s/pixh_%d.png", outdir, index);
-        pixWrite(fname, pixh, IFF_PNG);
+        pixWriteDebug(fname, pixh, IFF_PNG);
         pixDestroy(&pixh);
     }
     LEPT_FREE(outdir);
@@ -1090,7 +1090,7 @@ PIX     *pixv, *pixh;
  *          images.  No undercropping is applied before rendering.
  * </pre>
  */
-l_int32
+l_ok
 dewarpShowResults(L_DEWARPA   *dewa,
                   SARRAY      *sa,
                   BOXA        *boxa,
@@ -1154,7 +1154,7 @@ PIXA      *pixa;
         pixt2 = pixAddSingleTextblock(pixt1, bmf, bufstr, 0x0000ff00,
                                       L_ADD_BELOW, 0);
         snprintf(bufstr, sizeof(bufstr), "/tmp/lept/dewarp_pdfout/%05d", i);
-        pixWrite(bufstr, pixt2, IFF_JFIF_JPEG);
+        pixWriteDebug(bufstr, pixt2, IFF_JFIF_JPEG);
         pixaDestroy(&pixa);
         pixDestroy(&pixs);
         pixDestroy(&pixt1);
