@@ -24,15 +24,22 @@
  -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *====================================================================*/
 
-/*
- *  psio1.c
+/*!
+ * \file psio1.c
+ * <pre>
  *
  *    |=============================================================|
  *    |                         Important note                      |
  *    |=============================================================|
- *    | Some of these functions require libtiff, libjpeg and libz.  |
- *    | If you do not have these libraries, you must set            |
+ *    | Some of these functions require I/O libraries such as       |
+ *    | libtiff, libjpeg, and libz.  If you do not have these       |
+ *    | libraries, some calls will fail.                            |
+ *    |                                                             |
+ *    | You can manually deactivate all PostScript writing by       |
+ *    | setting this in environ.h:                                  |
+ *    | \code                                                       |
  *    |     #define  USE_PSIO     0                                 |
+ *    | \endcode                                                    |
  *    | in environ.h.  This will link psio1stub.c                   |
  *    |=============================================================|
  *
@@ -60,6 +67,7 @@
  *
  *     Write all images in a pixa out to PS
  *          l_int32          pixaWriteCompressedToPS()
+ *          l_int32          pixWriteCompressedToPS()
  *
  *  These PostScript converters are used in three different ways.
  *
@@ -96,6 +104,7 @@
  *  functions such as convertFilesToPS(), convertFilesFittedToPS()
  *  and convertSegmentedPagesToPS().  The function l_psWriteBoundingBox()
  *  sets a flag to give low-level control over this.
+ * </pre>
  */
 
 #include <string.h>
@@ -109,15 +118,16 @@
  *                Convert files in a directory to PS           *
  *-------------------------------------------------------------*/
 /*
- *  convertFilesToPS()
+ * \brief   convertFilesToPS()
  *
- *      Input:  dirin (input directory)
- *              substr (<optional> substring filter on filenames; can be NULL)
- *              res (typ. 300 or 600 ppi)
- *              fileout (output ps file)
- *      Return: 0 if OK, 1 on error
+ * \param[in]  dirin    input directory
+ * \param[in]  substr   [optional] substring filter on filenames; can be NULL
+ * \param[in]  res      typ. 300 or 600 ppi
+ * \param[in]  fileout  output ps file
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) This generates a PS file for all image files in a specified
  *          directory that contain the substr pattern to be matched.
  *      (2) Each image is written to a separate page in the output PS file.
@@ -143,8 +153,9 @@
  *          the image to the output resolution before wrapping in PS.
  *      (6) The "canvas" on which the image is rendered, at the given
  *          output resolution, is a standard page size (8.5 x 11 in).
+ * </pre>
  */
-l_int32
+l_ok
 convertFilesToPS(const char  *dirin,
                  const char  *substr,
                  l_int32      res,
@@ -178,23 +189,26 @@ SARRAY  *sa;
 
 
 /*
- *  sarrayConvertFilesToPS()
+
+ * \brief    sarrayConvertFilesToPS()
  *
- *      Input:  sarray (of full path names)
- *              res (typ. 300 or 600 ppi)
- *              fileout (output ps file)
- *      Return: 0 if OK, 1 on error
+ * \param[in]  sarray   of full path names
+ * \param[in]  res      typ. 300 or 600 ppi
+ * \param[in]  fileout  output ps file
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
- *      (1) See convertFilesToPS()
+ * <pre>
+ * Notes:
+ *     (1) See convertFilesToPS()
+ * </pre>
  */
-l_int32
+l_ok
 sarrayConvertFilesToPS(SARRAY      *sa,
                        l_int32      res,
                        const char  *fileout)
 {
 char    *fname;
-l_int32  i, nfiles, index, firstfile, ret, format;
+l_int32  i, nfiles, index, ret, format;
 
     PROCNAME("sarrayConvertFilesToPS");
 
@@ -210,7 +224,6 @@ l_int32  i, nfiles, index, firstfile, ret, format;
         L_WARNING("res is typically in the range 300-600 ppi\n", procName);
 
     nfiles = sarrayGetCount(sa);
-    firstfile = TRUE;
     for (i = 0, index = 0; i < nfiles; i++) {
         fname = sarrayGetString(sa, i, L_NOCOPY);
         ret = pixReadHeader(fname, &format, NULL, NULL, NULL, NULL, NULL);
@@ -218,7 +231,7 @@ l_int32  i, nfiles, index, firstfile, ret, format;
         if (format == IFF_UNKNOWN)
             continue;
 
-        writeImageCompressedToPSFile(fname, fileout, res, &firstfile, &index);
+        writeImageCompressedToPSFile(fname, fileout, res, &index);
     }
 
     return 0;
@@ -226,15 +239,17 @@ l_int32  i, nfiles, index, firstfile, ret, format;
 
 
 /*
- *  convertFilesFittedToPS()
+ * \brief   convertFilesFittedToPS()
  *
- *      Input:  dirin (input directory)
- *              substr (<optional> substring filter on filenames; can be NULL)
- *              xpts, ypts (desired size in printer points; use 0 for default)
- *              fileout (output ps file)
- *      Return: 0 if OK, 1 on error
+ * \param[in]  dirin    input directory
+ * \param[in]  substr   [optional] substring filter on filenames; can be NULL)
+ * \param[in]  xpts     desired size in printer points; use 0 for default
+ * \param[in]  ypts     desired size in printer points; use 0 for default
+ * \param[in]  fileout  output ps file
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) This generates a PS file for all files in a specified directory
  *          that contain the substr pattern to be matched.
  *      (2) Each image is written to a separate page in the output PS file.
@@ -250,10 +265,11 @@ l_int32  i, nfiles, index, firstfile, ret, format;
  *          size in printer points.  Use 0.0 for xpts or ypts to get
  *          the default value, which is 612.0 or 792.0, rsp.
  *      (5) The size of the PostScript file is independent of the resolution,
- *          because the entire file is encoded.  The @xpts and @ypts
+ *          because the entire file is encoded.  The %xpts and %ypts
  *          parameter tells the PS decomposer how to render the page.
+ * </pre>
  */
-l_int32
+l_ok
 convertFilesFittedToPS(const char  *dirin,
                        const char  *substr,
                        l_float32    xpts,
@@ -292,24 +308,27 @@ SARRAY  *sa;
 
 
 /*
- *  sarrayConvertFilesFittedToPS()
+ * \brief  sarrayConvertFilesFittedToPS()
  *
- *      Input:  sarray (of full path names)
- *              xpts, ypts (desired size in printer points; use 0 for default)
- *              fileout (output ps file)
- *      Return: 0 if OK, 1 on error
+ * \param[in]  sarray   of full path names
+ * \param[in]  xpts     desired size in printer points; use 0 for default
+ * \param[in]  ypts     desired size in printer points; use 0 for default
+ * \param[in]  fileout  output ps file
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
- *      (1) See convertFilesFittedToPS()
+ * <pre>
+ * Notes:
+ *     (1) See convertFilesFittedToPS()
+ * </pre>
  */
-l_int32
+l_ok
 sarrayConvertFilesFittedToPS(SARRAY      *sa,
                              l_float32    xpts,
                              l_float32    ypts,
                              const char  *fileout)
 {
 char    *fname;
-l_int32  ret, i, w, h, nfiles, index, firstfile, format, res;
+l_int32  ret, i, w, h, nfiles, index, format, res;
 
     PROCNAME("sarrayConvertFilesFittedToPS");
 
@@ -329,7 +348,6 @@ l_int32  ret, i, w, h, nfiles, index, firstfile, format, res;
         L_WARNING("xpts,ypts are typically in the range 500-800\n", procName);
 
     nfiles = sarrayGetCount(sa);
-    firstfile = TRUE;
     for (i = 0, index = 0; i < nfiles; i++) {
         fname = sarrayGetString(sa, i, L_NOCOPY);
         ret = pixReadHeader(fname, &format, &w, &h, NULL, NULL, NULL);
@@ -343,7 +361,7 @@ l_int32  ret, i, w, h, nfiles, index, firstfile, format, res;
         else
             res = (l_int32)((l_float32)h * 72.0 / ypts);
 
-        writeImageCompressedToPSFile(fname, fileout, res, &firstfile, &index);
+        writeImageCompressedToPSFile(fname, fileout, res, &index);
     }
 
     return 0;
@@ -351,31 +369,30 @@ l_int32  ret, i, w, h, nfiles, index, firstfile, format, res;
 
 
 /*
- *  writeImageCompressedToPSFile()
+ * \brief   writeImageCompressedToPSFile()
  *
- *      Input:  filein (input image file)
- *              fileout (output ps file)
- *              res (output printer resolution)
- *              &firstfile (<input and return> 1 if the first image;
- *                          0 otherwise)
- *              &index (<input and return> index of image in output ps file)
- *      Return: 0 if OK, 1 on error
+ * \param[in]     filein      input image file
+ * \param[in]     fileout     output ps file
+ * \param[in]     res         output printer resolution
+ * \param[in,out] pindex      index of image in output ps file
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) This wraps a single page image in PS.
  *      (2) The input file can be in any format.  It is compressed as follows:
  *             * if in tiffg4  -->  use ccittg4
  *             * if in jpeg    -->  use dct
  *             * all others    -->  use flate
- *      (3) Before the first call, set @firstpage = 1.  After writing
- *          the first page, it will be set to 0.
- *      (4) @index is incremented if the page is successfully written.
+ *      (3) Before the first call, set %index = 0.  %index is incremented
+ *          if the page is successfully written.  It is used to decide
+ *          whether to write (index == 0) or append (index > 0) to the file.
+ * </pre>
  */
-l_int32
+l_ok
 writeImageCompressedToPSFile(const char  *filein,
                              const char  *fileout,
                              l_int32      res,
-                             l_int32     *pfirstfile,
                              l_int32     *pindex)
 {
 const char  *op;
@@ -383,8 +400,8 @@ l_int32      format, retval;
 
     PROCNAME("writeImageCompressedToPSFile");
 
-    if (!pfirstfile || !pindex)
-        return ERROR_INT("&firstfile and &index not defined", procName, 1);
+    if (!pindex)
+        return ERROR_INT("&index not defined", procName, 1);
 
     findFileFormat(filein, &format);
     if (format == IFF_UNKNOWN) {
@@ -392,29 +409,18 @@ l_int32      format, retval;
         return 1;
     }
 
-    op = (*pfirstfile == TRUE) ? "w" : "a";
+    op = (*pindex == 0) ? "w" : "a";
     if (format == IFF_JFIF_JPEG) {
         retval = convertJpegToPS(filein, fileout, op, 0, 0,
                                  res, 1.0, *pindex + 1, TRUE);
-        if (retval == 0) {
-            *pfirstfile = FALSE;
-            (*pindex)++;
-        }
     } else if (format == IFF_TIFF_G4) {
         retval = convertG4ToPS(filein, fileout, op, 0, 0,
                                res, 1.0, *pindex + 1, FALSE, TRUE);
-        if (retval == 0) {
-            *pfirstfile = FALSE;
-            (*pindex)++;
-        }
     } else {  /* all other image formats */
         retval = convertFlateToPS(filein, fileout, op, 0, 0,
                                   res, 1.0, *pindex + 1, TRUE);
-        if (retval == 0) {
-            *pfirstfile = FALSE;
-            (*pindex)++;
-        }
     }
+    if (retval == 0) (*pindex)++;
 
     return retval;
 }
@@ -424,24 +430,26 @@ l_int32      format, retval;
  *              Convert mixed text/image files to PS           *
  *-------------------------------------------------------------*/
 /*
- *  convertSegmentedPagesToPS()
+ * \brief  convertSegmentedPagesToPS()
  *
- *      Input:  pagedir (input page image directory)
- *              pagestr (<optional> substring filter on page filenames;
- *                       can be NULL)
- *              maskdir (input mask image directory)
- *              maskstr (<optional> substring filter on mask filenames;
- *                       can be NULL)
- *              numpre (number of characters in name before number)
- *              numpost (number of characters in name after number)
- *              maxnum (only consider page numbers up to this value)
- *              textscale (scale of text output relative to pixs)
- *              imagescale (scale of image output relative to pixs)
- *              threshold (for binarization; typ. about 190; 0 for default)
- *              fileout (output ps file)
- *      Return: 0 if OK, 1 on error
+ * \param[in]     pagedir      input page image directory
+ * \param[in]     pagestr      [optional] substring filter on page filenames;
+ *                             can be NULL
+ * \param[in]     page_numpre  number of characters in page name before number
+ * \param[in]     maskdir      input mask image directory
+ * \param[in]     maskstr      [optional] substring filter on mask filenames;
+ *                             can be NULL
+ * \param[in]     mask_numpre  number of characters in mask name before number
+ * \param[in]     numpost      number of characters in names after number
+ * \param[in]     maxnum       only consider page numbers up to this value
+ * \param[in]     textscale    scale of text output relative to pixs
+ * \param[in]     imagescale   scale of image output relative to pixs
+ * \param[in]     threshold    for binarization; typ. about 190; 0 for default
+ * \param[in]     fileout      output ps file
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) This generates a PS file for all page image and mask files in two
  *          specified directories and that contain the page numbers as
  *          specified below.  The two directories can be the same, in which
@@ -458,28 +466,31 @@ l_int32      format, retval;
  *          compressed as G4 (i.e., tiff g4), and rendered by painting
  *          black through the resulting text mask.
  *      (4) The scaling is typically 2x down for the DCT component
- *          (@imagescale = 0.5) and 2x up for the G4 component
- *          (@textscale = 2.0).
+ *          (%imagescale = 0.5) and 2x up for the G4 component
+ *          (%textscale = 2.0).
  *      (5) The resolution is automatically set to fit to a
  *          letter-size (8.5 x 11 inch) page.
  *      (6) Both the DCT and the G4 encoding are PostScript level 2.
  *      (7) It is assumed that the page number is contained within
  *          the basename (the filename without directory or extension).
- *          @numpre is the number of characters in the basename
- *          preceeding the actual page numer; @numpost is the number
- *          following the page number.  Note: the same numbers must be
- *          applied to both the page and mask image names.
+ *          %page_numpre is the number of characters in the page basename
+ *          preceding the actual page number; %mask_numpre is likewise for
+ *          the mask basename; %numpost is the number of characters
+ *          following the page number.  For example, for mask name
+ *          mask_006.tif, mask_numpre = 5 ("mask_).
  *      (8) To render a page as is -- that is, with no thresholding
  *          of any pixels -- use a mask in the mask directory that is
  *          full size with all pixels set to 1.  If the page is 1 bpp,
  *          it is not necessary to have a mask.
+ * </pre>
  */
-l_int32
+l_ok
 convertSegmentedPagesToPS(const char  *pagedir,
                           const char  *pagestr,
+                          l_int32      page_numpre,
                           const char  *maskdir,
                           const char  *maskstr,
-                          l_int32      numpre,
+                          l_int32      mask_numpre,
                           l_int32      numpost,
                           l_int32      maxnum,
                           l_float32    textscale,
@@ -506,10 +517,10 @@ SARRAY  *sapage, *samask;
 
         /* Get numbered full pathnames; max size of sarray is maxnum */
     sapage = getNumberedPathnamesInDirectory(pagedir, pagestr,
-                                             numpre, numpost, maxnum);
+                                             page_numpre, numpost, maxnum);
     samask = getNumberedPathnamesInDirectory(maskdir, maskstr,
-                                             numpre, numpost, maxnum);
-    sarrayPadToSameSize(sapage, samask, (char *)"");
+                                             mask_numpre, numpost, maxnum);
+    sarrayPadToSameSize(sapage, samask, "");
     if ((npages = sarrayGetCount(sapage)) == 0) {
         sarrayDestroy(&sapage);
         sarrayDestroy(&samask);
@@ -536,20 +547,21 @@ SARRAY  *sapage, *samask;
 
 
 /*
- *  pixWriteSegmentedPageToPS()
+ * \brief   pixWriteSegmentedPageToPS()
  *
- *      Input:  pixs (all depths; colormap ok)
- *              pixm (<optional> 1 bpp segmentation mask over image region)
- *              textscale (scale of text output relative to pixs)
- *              imagescale (scale of image output relative to pixs)
- *              threshold (threshold for binarization; typ. 190)
- *              pageno (page number in set; use 1 for new output file)
- *              fileout (output ps file)
- *      Return: 0 if OK, 1 on error
+ * \param[in]     pixs      all depths; colormap ok
+ * \param[in]     pixm      [optional] 1 bpp segmentation mask over image region
+ * \param[in]     textscale   scale of text output relative to pixs
+ * \param[in]     imagescale  scale of image output relative to pixs
+ * \param[in]     threshold   for binarization; typ. about 190; 0 for default
+ * \param[in]     pageno    page number in set; use 1 for new output file
+ * \param[in]     fileout   output ps file
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) This generates the PS string for a mixed text/image page,
- *          and adds it to an existing file if @pageno > 1.
+ *          and adds it to an existing file if %pageno > 1.
  *          The PS output is determined by fitting the result to
  *          a letter-size (8.5 x 11 inch) page.
  *      (2) The two images (pixs and pixm) are at the same resolution
@@ -558,18 +570,19 @@ SARRAY  *sapage, *samask;
  *          PS file.
  *      (3) pixb is the text component.  In the PostScript world, we think of
  *          it as a mask through which we paint black.  It is produced by
- *          scaling pixs by @textscale, and thresholding to 1 bpp.
+ *          scaling pixs by %textscale, and thresholding to 1 bpp.
  *      (4) pixc is the image component, which is that part of pixs under
- *          the mask pixm.  It is scaled from pixs by @imagescale.
+ *          the mask pixm.  It is scaled from pixs by %imagescale.
  *      (5) Typical values are textscale = 2.0 and imagescale = 0.5.
  *      (6) If pixm == NULL, the page has only text.  If it is all black,
  *          the page is all image and has no text.
  *      (7) This can be used to write a multi-page PS file, by using
  *          sequential page numbers with the same output file.  It can
  *          also be used to write separate PS files for each page,
- *          by using different output files with @pageno = 0 or 1.
+ *          by using different output files with %pageno = 0 or 1.
+ * </pre>
  */
-l_int32
+l_ok
 pixWriteSegmentedPageToPS(PIX         *pixs,
                           PIX         *pixm,
                           l_float32    textscale,
@@ -616,7 +629,7 @@ PIX       *pixmi, *pixmis, *pixt, *pixg, *pixsc, *pixb, *pixc;
         pixb = pixClone(pixs);
         pixc = NULL;
     } else {
-        pixt = pixConvertTo8Or32(pixs, 0, 0);  /* this can be a clone of pixs */
+        pixt = pixConvertTo8Or32(pixs, L_CLONE, 0);  /* clone if possible */
 
             /* Get the binary text mask.  Note that pixg cannot be a
              * clone of pixs, because it may be altered by pixSetMasked(). */
@@ -684,20 +697,21 @@ PIX       *pixmi, *pixmis, *pixt, *pixg, *pixsc, *pixb, *pixc;
 
 
 /*
- *  pixWriteMixedToPS()
+ * \brief  pixWriteMixedToPS()
  *
- *      Input:  pixb (<optionall> 1 bpp "mask"; typically for text)
- *              pixc (<optional> 8 or 32 bpp image regions)
- *              scale (relative scale factor for rendering pixb
- *                    relative to pixc; typ. 4.0)
- *              pageno (page number in set; use 1 for new output file)
- *              fileout (output ps file)
- *      Return: 0 if OK, 1 on error
+ * \param[in]     pixb      [optional] 1 bpp mask; typically for text
+ * \param[in]     pixc      [optional] 8 or 32 bpp image regions
+ * \param[in]     scale     scale factor for rendering pixb, relative to pixc;
+ *                          typ. 4.0
+ * \param[in]     pageno    page number in set; use 1 for new output file
+ * \param[in]     fileout   output ps file
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) This low level function generates the PS string for a mixed
  *          text/image page, and adds it to an existing file if
- *          @pageno > 1.
+ *          %pageno > 1.
  *      (2) The two images (pixb and pixc) are typically generated at the
  *          resolution that they will be rendered in the PS file.
  *      (3) pixb is the text component.  In the PostScript world, we think of
@@ -706,10 +720,10 @@ PIX       *pixmi, *pixmis, *pixt, *pixg, *pixsc, *pixb, *pixc;
  *          white in the rest of the page.  To minimize the size of the
  *          PS file, it should be rendered at a resolution that is at
  *          least equal to its actual resolution.
- *      (5) @scale gives the ratio of resolution of pixb to pixc.
+ *      (5) %scale gives the ratio of resolution of pixb to pixc.
  *          Typical resolutions are: 600 ppi for pixb, 150 ppi for pixc;
- *          so @scale = 4.0.  If one of the images is not defined,
- *          the value of @scale is ignored.
+ *          so %scale = 4.0.  If one of the images is not defined,
+ *          the value of %scale is ignored.
  *      (6) We write pixc with DCT compression (jpeg).  This is followed
  *          by painting the text as black through the mask pixb.  If
  *          pixc doesn't exist (alltext), we write the text with the
@@ -717,16 +731,16 @@ PIX       *pixmi, *pixmis, *pixt, *pixg, *pixsc, *pixb, *pixc;
  *          because ghostscript's ps2pdf is flaky when the latter is used.
  *      (7) The actual output resolution is determined by fitting the
  *          result to a letter-size (8.5 x 11 inch) page.
+ * <pre>
  */
-l_int32
+l_ok
 pixWriteMixedToPS(PIX         *pixb,
                   PIX         *pixc,
                   l_float32    scale,
                   l_int32      pageno,
                   const char  *fileout)
 {
-const char   tnameb[] = "/tmp/junk_pix_write_mixed.tif";
-const char   tnamec[] = "/tmp/junk_pix_write_mixed.jpg";
+char        *tname;
 const char  *op;
 l_int32      resb, resc, endpage, maskop, ret;
 
@@ -748,11 +762,14 @@ l_int32      resb, resc, endpage, maskop, ret;
 
         /* Write the jpeg image first */
     if (pixc) {
-        pixWrite(tnamec, pixc, IFF_JFIF_JPEG);
+        tname = l_makeTempFilename();
+        pixWrite(tname, pixc, IFF_JFIF_JPEG);
         endpage = (pixb) ? FALSE : TRUE;
         op = (pageno <= 1) ? "w" : "a";
-        ret = convertJpegToPS(tnamec, fileout, op, 0, 0, resc, 1.0,
+        ret = convertJpegToPS(tname, fileout, op, 0, 0, resc, 1.0,
                               pageno, endpage);
+        lept_rmfile(tname);
+        LEPT_FREE(tname);
         if (ret)
             return ERROR_INT("jpeg data not written", procName, 1);
     }
@@ -760,11 +777,14 @@ l_int32      resb, resc, endpage, maskop, ret;
         /* Write the binary data, either directly or, if there is
          * a jpeg image on the page, through the mask. */
     if (pixb) {
-        pixWrite(tnameb, pixb, IFF_TIFF_G4);
+        tname = l_makeTempFilename();
+        pixWrite(tname, pixb, IFF_TIFF_G4);
         op = (pageno <= 1 && !pixc) ? "w" : "a";
         maskop = (pixc) ? 1 : 0;
-        ret = convertG4ToPS(tnameb, fileout, op, 0, 0, resb, 1.0,
+        ret = convertG4ToPS(tname, fileout, op, 0, 0, resb, 1.0,
                             pageno, maskop, 1);
+        lept_rmfile(tname);
+        LEPT_FREE(tname);
         if (ret)
             return ERROR_INT("tiff data not written", procName, 1);
     }
@@ -777,36 +797,37 @@ l_int32      resb, resc, endpage, maskop, ret;
  *            Convert any image file to PS for embedding       *
  *-------------------------------------------------------------*/
 /*
- *  convertToPSEmbed()
+ * \brief  convertToPSEmbed()
  *
- *      Input:  filein (input image file -- any format)
- *              fileout (output ps file)
- *              level (compression: 1 (uncompressed), 2 or 3)
- *      Return: 0 if OK, 1 on error
+ * \param[in]     filein    input image file, any format
+ * \param[in]     fileout   output ps file
+ * \param[in]     level     PostScript compression: 1 (uncompressed), 2 or 3
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) This is a wrapper function that generates a PS file with
  *          a bounding box, from any input image file.
  *      (2) Do the best job of compression given the specified level.
- *          @level=3 does flate compression on anything that is not
+ *          %level=3 does flate compression on anything that is not
  *          tiffg4 (1 bpp) or jpeg (8 bpp or rgb).
- *      (3) If @level=2 and the file is not tiffg4 or jpeg, it will
+ *      (3) If %level=2 and the file is not tiffg4 or jpeg, it will
  *          first be written to file as jpeg with quality = 75.
  *          This will remove the colormap and cause some degradation
  *          in the image.
  *      (4) The bounding box is required when a program such as TeX
  *          (through epsf) places and rescales the image.  It is
  *          sized for fitting the image to an 8.5 x 11.0 inch page.
+ * </pre>
  */
-l_int32
+l_ok
 convertToPSEmbed(const char  *filein,
                  const char  *fileout,
                  l_int32      level)
 {
-const char  nametif[] = "/tmp/junk_convert_ps_embed.tif";
-const char  namejpg[] = "/tmp/junk_convert_ps_embed.jpg";
-l_int32     d, format;
-PIX        *pix, *pixs;
+char    *tname;
+l_int32  d, format;
+PIX     *pix, *pixs;
 
     PROCNAME("convertToPSEmbed");
 
@@ -850,19 +871,22 @@ PIX        *pix, *pixs;
     if ((d == 2 || d == 4) && !pixGetColormap(pixs))
         pix = pixConvertTo8(pixs, 0);
     else if (d == 16)
-        pix = pixConvert16To8(pixs, 1);
+        pix = pixConvert16To8(pixs, L_MS_BYTE);
     else
         pix = pixRemoveColormap(pixs, REMOVE_CMAP_BASED_ON_SRC);
 
     d = pixGetDepth(pix);
+    tname = l_makeTempFilename();
     if (d == 1) {
-        pixWrite(nametif, pix, IFF_TIFF_G4);
-        convertG4ToPSEmbed(nametif, fileout);
+        pixWrite(tname, pix, IFF_TIFF_G4);
+        convertG4ToPSEmbed(tname, fileout);
     } else {
-        pixWrite(namejpg, pix, IFF_JFIF_JPEG);
-        convertJpegToPSEmbed(namejpg, fileout);
+        pixWrite(tname, pix, IFF_JFIF_JPEG);
+        convertJpegToPSEmbed(tname, fileout);
     }
 
+    lept_rmfile(tname);
+    LEPT_FREE(tname);
     pixDestroy(&pix);
     pixDestroy(&pixs);
     return 0;
@@ -873,38 +897,31 @@ PIX        *pix, *pixs;
  *              Write all images in a pixa out to PS           *
  *-------------------------------------------------------------*/
 /*
- *  pixaWriteCompressedToPS()
+ * \brief  pixaWriteCompressedToPS()
  *
- *      Input:  pixa (any set of images)
- *              fileout (output ps file)
- *              res (of input image)
- *              level (compression: 2 or 3)
- *      Return: 0 if OK, 1 on error
+ * \param[in]     pixa      any set of images
+ * \param[in]     fileout   output ps file
+ * \param[in]     res       resolution for the set of input images
+ * \param[in]     level     PostScript compression capability: 2 or 3
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
- *      (1) This generates a PS file of multiple page images, all
- *          with bounding boxes.
- *      (2) It compresses to:
- *              cmap + level2:        jpeg
- *              cmap + level3:        flate
- *              1 bpp:                tiffg4
- *              2 or 4 bpp + level2:  jpeg
- *              2 or 4 bpp + level3:  flate
- *              8 bpp:                jpeg
- *              16 bpp:               flate
- *              32 bpp:               jpeg
- *      (3) To generate a pdf, use: ps2pdf <infile.ps> <outfile.pdf>
+ * <pre>
+ * Notes:
+ *      (1) This generates a PostScript file of multiple page images,
+ *          all with bounding boxes.
+ *      (2) See pixWriteCompressedToPS() for details.
+ *      (3) To generate a pdf from %fileout, use:
+ *             ps2pdf <infile.ps> <outfile.pdf>
+ * </pre>
  */
-l_int32
+l_ok
 pixaWriteCompressedToPS(PIXA        *pixa,
                         const char  *fileout,
                         l_int32      res,
                         l_int32      level)
 {
-char     *tname, *g4_name, *jpeg_name, *png_name;
-l_int32   i, n, firstfile, index, writeout, d;
-PIX      *pix, *pixt;
-PIXCMAP  *cmap;
+l_int32  i, n, index, ret;
+PIX     *pix;
 
     PROCNAME("pixaWriteCompressedToPS");
 
@@ -917,66 +934,124 @@ PIXCMAP  *cmap;
         level = 2;
     }
 
-    n = pixaGetCount(pixa);
-    firstfile = TRUE;
     index = 0;
-    g4_name = genTempFilename("/tmp", "temp_compr.tif", 0, 0);
-    jpeg_name = genTempFilename("/tmp", "temp_compr.jpg", 0, 0);
-    png_name = genTempFilename("/tmp", "temp_compr.png", 0, 0);
+    n = pixaGetCount(pixa);
     for (i = 0; i < n; i++) {
-        writeout = TRUE;
         pix = pixaGetPix(pixa, i, L_CLONE);
-        d = pixGetDepth(pix);
-        cmap = pixGetColormap(pix);
-        if (d == 1) {
-            tname = g4_name;
-            pixWrite(tname, pix, IFF_TIFF_G4);
-        } else if (cmap) {
-            if (level == 2) {
-                pixt = pixConvertForPSWrap(pix);
-                tname = jpeg_name;
-                pixWrite(tname, pixt, IFF_JFIF_JPEG);
-                pixDestroy(&pixt);
-            } else {  /* level == 3 */
-                tname = png_name;
-                pixWrite(tname, pix, IFF_PNG);
-            }
-        } else if (d == 16) {
-            if (level == 2)
-                L_WARNING("d = 16; must write out flate\n", procName);
-            tname = png_name;
-            pixWrite(tname, pix, IFF_PNG);
-        } else if (d == 2 || d == 4) {
-            if (level == 2) {
-                pixt = pixConvertTo8(pix, 0);
-                tname = jpeg_name;
-                pixWrite(tname, pixt, IFF_JFIF_JPEG);
-                pixDestroy(&pixt);
-            } else {  /* level == 3 */
-                tname = png_name;
-                pixWrite(tname, pix, IFF_PNG);
-            }
-        } else if (d == 8 || d == 32) {
-            tname = jpeg_name;
-            pixWrite(tname, pix, IFF_JFIF_JPEG);
-        } else {  /* shouldn't happen */
-            L_ERROR("invalid depth: %d\n", procName, d);
-            writeout = FALSE;
-        }
+        ret = pixWriteCompressedToPS(pix, fileout, res, level, &index);
+        if (ret) L_ERROR("PS string not written for image %d\n", procName, i);
         pixDestroy(&pix);
-
-        if (writeout)
-            writeImageCompressedToPSFile(tname, fileout, res,
-                                         &firstfile, &index);
     }
-
-    FREE(g4_name);
-    FREE(jpeg_name);
-    FREE(png_name);
     return 0;
 }
 
 
+/*
+ * \brief  pixWriteCompressedToPS()
+ *
+ * \param[in]      pix        any depth; colormap OK
+ * \param[in]      fileout    output ps file
+ * \param[in]      res        of input image
+ * \param[in]      level      PostScript compression capability: 2 or 3
+ * \param[in,out]  pindex     index of image in output ps file
+ * \return  0 if OK, 1 on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) This generates a PostScript string for %pix, and writes it
+ *          to a file, with a bounding box.
+ *      (2) *pindex keeps track of the number of images that have been
+ *          written to %fileout.  If this is the first image to be
+ *          converted, set *pindex == 0 before passing it in.  If the
+ *          PostScript string is successfully generated, this will increment
+ *          *pindex.  If *pindex > 0, the PostScript string will be
+ *          appended to %fileout.
+ *      (3) PostScript level 2 enables lossless tiffg4 and lossy jpeg
+ *          compression.  Level 3 adds lossless flate (essentially gzip)
+ *          compression.
+ *          * For images with a colormap, lossless flate is often better in
+ *            both quality and size than jpeg.
+ *          * The decision for images without a colormap affects compression
+ *            efficiency: %level2 (jpeg) is usually better than %level3 (flate)
+ *          * Because jpeg does not handle 16 bpp, if %level == 2, the image
+ *            is converted to 8 bpp (using MSB) and compressed with jpeg,
+ *              cmap + level2:        jpeg
+ *              cmap + level3:        flate
+ *              1 bpp:                tiffg4
+ *              2 or 4 bpp + level2:  jpeg
+ *              2 or 4 bpp + level3:  flate
+ *              8 bpp + level2:       jpeg
+ *              8 bpp + level3:       flate
+ *              16 bpp + level2:      jpeg   [converted to 8 bpp, with warning]
+ *              16 bpp + level3:      flate
+ *              32 bpp + level2:      jpeg
+ *              32 bpp + level3:      flate
+ * </pre>
+ */
+l_ok
+pixWriteCompressedToPS(PIX         *pix,
+                       const char  *fileout,
+                       l_int32      res,
+                       l_int32      level,
+                       l_int32     *pindex)
+{
+char     *tname;
+l_int32   i, n, writeout, d;
+PIX      *pixt;
+PIXCMAP  *cmap;
+
+    PROCNAME("pixWriteCompressedToPS");
+
+    if (!pix)
+        return ERROR_INT("pix not defined", procName, 1);
+    if (!fileout)
+        return ERROR_INT("fileout not defined", procName, 1);
+    if (level != 2 && level != 3) {
+        L_ERROR("only levels 2 and 3 permitted; using level 2\n", procName);
+        level = 2;
+    }
+    if (!pindex)
+        return ERROR_INT("&index not defined", procName, 1);
+
+    tname = l_makeTempFilename();
+    writeout = TRUE;
+    d = pixGetDepth(pix);
+    cmap = pixGetColormap(pix);
+    if (d == 1) {
+        pixWrite(tname, pix, IFF_TIFF_G4);
+    } else if (level == 3) {
+        pixWrite(tname, pix, IFF_PNG);
+    } else {  /* level == 2 */
+        if (cmap) {
+            pixt = pixConvertForPSWrap(pix);
+            pixWrite(tname, pixt, IFF_JFIF_JPEG);
+            pixDestroy(&pixt);
+        } else if (d == 16) {
+            L_WARNING("d = 16; converting to 8 bpp for jpeg\n", procName);
+            pixt = pixConvert16To8(pix, L_MS_BYTE);
+            pixWrite(tname, pixt, IFF_JFIF_JPEG);
+            pixDestroy(&pixt);
+        } else if (d == 2 || d == 4) {
+            pixt = pixConvertTo8(pix, 0);
+            pixWrite(tname, pixt, IFF_JFIF_JPEG);
+            pixDestroy(&pixt);
+        } else if (d == 8 || d == 32) {
+            pixWrite(tname, pix, IFF_JFIF_JPEG);
+        } else {  /* shouldn't happen */
+            L_ERROR("invalid depth with level 2: %d\n", procName, d);
+            writeout = FALSE;
+        }
+    }
+
+    if (writeout)
+        writeImageCompressedToPSFile(tname, fileout, res, pindex);
+
+    if (lept_rmfile(tname) != 0)
+        L_ERROR("temp file %s was not deleted\n", procName, tname);
+    LEPT_FREE(tname);
+    return 0;
+}
+
 /* --------------------------------------------*/
 #endif  /* USE_PSIO */
 /* --------------------------------------------*/
