@@ -38,89 +38,96 @@
 #if  !USE_PSIO   /* defined in environ.h */
 /* --------------------------------------------*/
 
-l_int32 convertFilesToPS(const char *dirin, const char *substr,
-                         l_int32 res, const char *fileout)
+l_ok convertFilesToPS(const char *dirin, const char *substr,
+                      l_int32 res, const char *fileout)
 {
     return ERROR_INT("function not present", "convertFilesToPS", 1);
 }
 
 /* ----------------------------------------------------------------------*/
 
-l_int32 sarrayConvertFilesToPS(SARRAY *sa, l_int32 res, const char *fileout)
+l_ok sarrayConvertFilesToPS(SARRAY *sa, l_int32 res, const char *fileout)
 {
     return ERROR_INT("function not present", "sarrayConvertFilesToPS", 1);
 }
 
 /* ----------------------------------------------------------------------*/
 
-l_int32 convertFilesFittedToPS(const char *dirin, const char *substr,
-                               l_float32 xpts, l_float32 ypts,
-                               const char *fileout)
+l_ok convertFilesFittedToPS(const char *dirin, const char *substr,
+                            l_float32 xpts, l_float32 ypts,
+                            const char *fileout)
 {
     return ERROR_INT("function not present", "convertFilesFittedToPS", 1);
 }
 
 /* ----------------------------------------------------------------------*/
 
-l_int32 sarrayConvertFilesFittedToPS(SARRAY *sa, l_float32 xpts,
-                                     l_float32 ypts, const char *fileout)
+l_ok sarrayConvertFilesFittedToPS(SARRAY *sa, l_float32 xpts,
+                                  l_float32 ypts, const char *fileout)
 {
     return ERROR_INT("function not present", "sarrayConvertFilesFittedToPS", 1);
 }
 
 /* ----------------------------------------------------------------------*/
 
-l_int32 writeImageCompressedToPSFile(const char *filein, const char *fileout,
-                                     l_int32 res, l_int32 *pfirstfile,
-                                     l_int32 *pindex)
+l_ok writeImageCompressedToPSFile(const char *filein, const char *fileout,
+                                  l_int32 res, l_int32 *pindex)
 {
     return ERROR_INT("function not present", "writeImageCompressedToPSFile", 1);
 }
 
 /* ----------------------------------------------------------------------*/
 
-l_int32 convertSegmentedPagesToPS(const char *pagedir, const char *pagestr,
-                                  l_int32 page_numpre, const char *maskdir,
-                                  const char *maskstr, l_int32 mask_numpre,
-                                  l_int32 numpost, l_int32 maxnum,
-                                  l_float32 textscale, l_float32 imagescale,
-                                  l_int32 threshold, const char *fileout)
+l_ok convertSegmentedPagesToPS(const char *pagedir, const char *pagestr,
+                               l_int32 page_numpre, const char *maskdir,
+                               const char *maskstr, l_int32 mask_numpre,
+                               l_int32 numpost, l_int32 maxnum,
+                               l_float32 textscale, l_float32 imagescale,
+                               l_int32 threshold, const char *fileout)
 {
     return ERROR_INT("function not present", "convertSegmentedPagesToPS", 1);
 }
 
 /* ----------------------------------------------------------------------*/
 
-l_int32 pixWriteSegmentedPageToPS(PIX *pixs, PIX *pixm, l_float32 textscale,
-                                  l_float32 imagescale, l_int32 threshold,
-                                  l_int32 pageno, const char *fileout)
+l_ok pixWriteSegmentedPageToPS(PIX *pixs, PIX *pixm, l_float32 textscale,
+                               l_float32 imagescale, l_int32 threshold,
+                               l_int32 pageno, const char *fileout)
 {
     return ERROR_INT("function not present", "pixWriteSegmentedPagesToPS", 1);
 }
 
 /* ----------------------------------------------------------------------*/
 
-l_int32 pixWriteMixedToPS(PIX *pixb, PIX *pixc, l_float32 scale,
-                          l_int32 pageno, const char *fileout)
+l_ok pixWriteMixedToPS(PIX *pixb, PIX *pixc, l_float32 scale,
+                       l_int32 pageno, const char *fileout)
 {
     return ERROR_INT("function not present", "pixWriteMixedToPS", 1);
 }
 
 /* ----------------------------------------------------------------------*/
 
-l_int32 convertToPSEmbed(const char *filein, const char *fileout, l_int32 level)
+l_ok convertToPSEmbed(const char *filein, const char *fileout, l_int32 level)
 {
     return ERROR_INT("function not present", "convertToPSEmbed", 1);
 }
 
 /* ----------------------------------------------------------------------*/
 
-l_int32 pixaWriteCompressedToPS(PIXA *pixa, const char *fileout,
-                                l_int32 res, l_int32 level)
+l_ok pixaWriteCompressedToPS(PIXA *pixa, const char *fileout,
+                             l_int32 res, l_int32 level)
 {
     return ERROR_INT("function not present", "pixaWriteCompressedtoPS", 1);
 }
 
+/* ----------------------------------------------------------------------*/
+
+l_ok pixWriteCompressedToPS(PIX *pix, const char *fileout, l_int32 res,
+                            l_int32 level, l_int32 *pindex)
+{
+    return ERROR_INT("function not present", "pixWriteCompressedtoPS", 1);
+}
+
 /* --------------------------------------------*/
 #endif  /* !USE_PSIO */
 /* --------------------------------------------*/
