@@ -29,6 +29,16 @@
  * \file  ptafunc1.c
  * <pre>
  *
+ *      --------------------------------------
+ *      This file has these Pta utilities:
+ *         - simple rearrangements
+ *         - geometric analysis
+ *         - min/max and filtering
+ *         - least squares fitting
+ *         - interconversions with Pix and Numa
+ *         - display into a pix
+ *      --------------------------------------
+ *
  *      Simple rearrangements
  *           PTA      *ptaSubsample()
  *           l_int32   ptaJoin()
@@ -104,7 +114,7 @@
  * \brief   ptaSubsample()
  *
  * \param[in]    ptas
- * \param[in]    subfactor subsample factor, >= 1
+ * \param[in]    subfactor    subsample factor, >= 1
  * \return  ptad evenly sampled pt values from ptas, or NULL on error
  */
 PTA *
@@ -137,10 +147,10 @@ PTA       *ptad;
 /*!
  * \brief   ptaJoin()
  *
- * \param[in]    ptad  dest pta; add to this one
- * \param[in]    ptas  source pta; add from this one
- * \param[in]    istart  starting index in ptas
- * \param[in]    iend  ending index in ptas; use -1 to cat all
+ * \param[in]    ptad     dest pta; add to this one
+ * \param[in]    ptas     source pta; add from this one
+ * \param[in]    istart   starting index in ptas
+ * \param[in]    iend     ending index in ptas; use -1 to cat all
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -150,7 +160,7 @@ PTA       *ptad;
  *      (3) if ptas == NULL, this is a no-op
  * </pre>
  */
-l_int32
+l_ok
 ptaJoin(PTA     *ptad,
         PTA     *ptas,
         l_int32  istart,
@@ -185,10 +195,10 @@ l_int32  n, i, x, y;
 /*!
  * \brief   ptaaJoin()
  *
- * \param[in]    ptaad  dest ptaa; add to this one
- * \param[in]    ptaas  source ptaa; add from this one
- * \param[in]    istart  starting index in ptaas
- * \param[in]    iend  ending index in ptaas; use -1 to cat all
+ * \param[in]    ptaad    dest ptaa; add to this one
+ * \param[in]    ptaas    source ptaa; add from this one
+ * \param[in]    istart   starting index in ptaas
+ * \param[in]    iend     ending index in ptaas; use -1 to cat all
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -198,7 +208,7 @@ l_int32  n, i, x, y;
  *      (3) if ptas == NULL, this is a no-op
  * </pre>
  */
-l_int32
+l_ok
 ptaaJoin(PTAA    *ptaad,
          PTAA    *ptaas,
          l_int32  istart,
@@ -235,7 +245,7 @@ PTA     *pta;
  * \brief   ptaReverse()
  *
  * \param[in]    ptas
- * \param[in]    type  0 for float values; 1 for integer values
+ * \param[in]    type     0 for float values; 1 for integer values
  * \return  ptad reversed pta, or NULL on error
  */
 PTA  *
@@ -302,7 +312,7 @@ PTA       *ptad;
  * \brief   ptaCyclicPerm()
  *
  * \param[in]    ptas
- * \param[in]    xs, ys  start point; must be in ptas
+ * \param[in]    xs, ys     start point; must be in ptas
  * \return  ptad cyclic permutation, starting and ending at (xs, ys,
  *              or NULL on error
  *
@@ -367,7 +377,7 @@ PTA     *ptad;
  *
  * \param[in]    ptas
  * \param[in]    first    use 0 to select from the beginning
- * \param[in]    last     use 0 to select to the end
+ * \param[in]    last     use -1 to select to the end
  * \return  ptad, or NULL on error
  */
 PTA *
@@ -388,9 +398,14 @@ PTA       *ptad;
         return ptaCopy(ptas);
     }
     first = L_MAX(0, first);
-    if (last <= 0) last = n - 1;
+    if (last < 0) last = n - 1;
     if (first >= n)
         return (PTA *)ERROR_PTR("invalid first", procName, NULL);
+    if (last >= n) {
+        L_WARNING("last = %d is beyond max index = %d; adjusting\n",
+                  procName, last, n - 1);
+        last = n - 1;
+    }
     if (first > last)
         return (PTA *)ERROR_PTR("first > last", procName, NULL);
 
@@ -451,10 +466,10 @@ l_int32  n, i, x, y, minx, maxx, miny, maxy;
  * \brief   ptaGetRange()
  *
  * \param[in]    pta
- * \param[out]   pminx [optional] min value of x
- * \param[out]   pmaxx [optional] max value of x
- * \param[out]   pminy [optional] min value of y
- * \param[out]   pmaxy [optional] max value of y
+ * \param[out]   pminx    [optional] min value of x
+ * \param[out]   pmaxx    [optional] max value of x
+ * \param[out]   pminy    [optional] min value of y
+ * \param[out]   pmaxy    [optional] max value of y
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -464,7 +479,7 @@ l_int32  n, i, x, y, minx, maxx, miny, maxy;
  *          example, the pts can represent a general function y(x).
  * </pre>
  */
-l_int32
+l_ok
 ptaGetRange(PTA        *pta,
             l_float32  *pminx,
             l_float32  *pmaxx,
@@ -510,7 +525,7 @@ l_float32  x, y, minx, maxx, miny, maxy;
 /*!
  * \brief   ptaGetInsideBox()
  *
- * \param[in]    ptas input pts
+ * \param[in]    ptas    input pts
  * \param[in]    box
  * \return  ptad of pts in ptas that are inside the box, or NULL on error
  */
@@ -545,7 +560,7 @@ l_float32  x, y;
 /*!
  * \brief   pixFindCornerPixels()
  *
- * \param[in]    pixs 1 bpp
+ * \param[in]    pixs    1 bpp
  * \return  pta, or NULL on error
  *
  * <pre>
@@ -643,7 +658,7 @@ PTA       *pta;
  * \brief   ptaContainsPt()
  *
  * \param[in]    pta
- * \param[in]    x, y  point
+ * \param[in]    x, y     point
  * \return  1 if contained, 0 otherwise or on error
  */
 l_int32
@@ -746,9 +761,9 @@ PTA     *ptad;
 /*!
  * \brief   ptaPtInsidePolygon()
  *
- * \param[in]    pta vertices of a polygon
- * \param[in]    x, y point to be tested
- * \param[out]   pinside 1 if inside; 0 if outside or on boundary
+ * \param[in]    pta       vertices of a polygon
+ * \param[in]    x, y      point to be tested
+ * \param[out]   pinside   1 if inside; 0 if outside or on boundary
  * \return  1 if OK, 0 on error
  *
  *  The abs value of the sum of the angles subtended from a point by
@@ -796,8 +811,8 @@ l_float32  sum, x1, y1, x2, y2, xp1, yp1, xp2, yp2;
 /*!
  * \brief   l_angleBetweenVectors()
  *
- * \param[in]    x1, y1 end point of first vector
- * \param[in]    x2, y2 end point of second vector
+ * \param[in]    x1, y1     end point of first vector
+ * \param[in]    x2, y2     end point of second vector
  * \return  angle radians, or 0.0 on error
  *
  * <pre>
@@ -830,14 +845,14 @@ l_float64  ang;
  * \brief   ptaGetMinMax()
  *
  * \param[in]    pta
- * \param[out]   pxmin  [optional] min of x
- * \param[out]   pymin  [optional] min of y
- * \param[out]   pxmax  [optional] max of x
- * \param[out]   pymax  [optional] max of y
+ * \param[out]   pxmin   [optional] min of x
+ * \param[out]   pymin   [optional] min of y
+ * \param[out]   pxmax   [optional] max of x
+ * \param[out]   pymax   [optional] max of y
  * \return  0 if OK, 1 on error.  If pta is empty, requested
  *              values are returned as -1.0.
  */
-l_int32
+l_ok
 ptaGetMinMax(PTA        *pta,
              l_float32  *pxmin,
              l_float32  *pymin,
@@ -883,11 +898,11 @@ l_float32  x, y, xmin, ymin, xmax, ymax;
  * \brief   ptaSelectByValue()
  *
  * \param[in]    ptas
- * \param[in]    xth, yth threshold values
- * \param[in]    type L_SELECT_XVAL, L_SELECT_YVAL,
- *                    L_SELECT_IF_EITHER, L_SELECT_IF_BOTH
- * \param[in]    relation L_SELECT_IF_LT, L_SELECT_IF_GT,
- *                        L_SELECT_IF_LTE, L_SELECT_IF_GTE
+ * \param[in]    xth, yth    threshold values
+ * \param[in]    type        L_SELECT_XVAL, L_SELECT_YVAL,
+ *                           L_SELECT_IF_EITHER, L_SELECT_IF_BOTH
+ * \param[in]    relation    L_SELECT_IF_LT, L_SELECT_IF_GT,
+ *                           L_SELECT_IF_LTE, L_SELECT_IF_GTE
  * \return  ptad filtered set, or NULL on error
  */
 PTA *
@@ -954,8 +969,8 @@ PTA       *ptad;
 /*!
  * \brief   ptaCropToMask()
  *
- * \param[in]    ptas  input pta
- * \param[in]    pixm  1 bpp mask
+ * \param[in]    ptas    input pta
+ * \param[in]    pixm    1 bpp mask
  * \return  ptad  with only pts under the mask fg, or NULL on error
  */
 PTA *
@@ -996,9 +1011,9 @@ PTA      *ptad;
  * \brief   ptaGetLinearLSF()
  *
  * \param[in]    pta
- * \param[out]   pa  [optional] slope a of least square fit: y = ax + b
- * \param[out]   pb  [optional] intercept b of least square fit
- * \param[out]   pnafit [optional] numa of least square fit
+ * \param[out]   pa      [optional] slope a of least square fit: y = ax + b
+ * \param[out]   pb      [optional] intercept b of least square fit
+ * \param[out]   pnafit  [optional] numa of least square fit
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -1025,7 +1040,7 @@ PTA      *ptad;
  *          Get the nax array using ptaGetArrays(pta, &nax, NULL);
  * </pre>
  */
-l_int32
+l_ok
 ptaGetLinearLSF(PTA        *pta,
                 l_float32  *pa,
                 l_float32  *pb,
@@ -1098,10 +1113,10 @@ l_float32  *xa, *ya;
  * \brief   ptaGetQuadraticLSF()
  *
  * \param[in]    pta
- * \param[out]   pa  [optional] coeff a of LSF: y = ax^2 + bx + c
- * \param[out]   pb  [optional] coeff b of LSF: y = ax^2 + bx + c
- * \param[out]   pc  [optional] coeff c of LSF: y = ax^2 + bx + c
- * \param[out]   pnafit [optional] numa of least square fit
+ * \param[out]   pa      [optional] coeff a of LSF: y = ax^2 + bx + c
+ * \param[out]   pb      [optional] coeff b of LSF: y = ax^2 + bx + c
+ * \param[out]   pc      [optional] coeff c of LSF: y = ax^2 + bx + c
+ * \param[out]   pnafit  [optional] numa of least square fit
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -1126,7 +1141,7 @@ l_float32  *xa, *ya;
  *          Get the nax array using ptaGetArrays(pta, &nax, NULL);
  * </pre>
  */
-l_int32
+l_ok
 ptaGetQuadraticLSF(PTA        *pta,
                    l_float32  *pa,
                    l_float32  *pb,
@@ -1208,11 +1223,11 @@ l_float32   g[3];
  * \brief   ptaGetCubicLSF()
  *
  * \param[in]    pta
- * \param[out]   pa  [optional] coeff a of LSF: y = ax^3 + bx^2 + cx + d
- * \param[out]   pb  [optional] coeff b of LSF
- * \param[out]   pc  [optional] coeff c of LSF
- * \param[out]   pd  [optional] coeff d of LSF
- * \param[out]   pnafit [optional] numa of least square fit
+ * \param[out]   pa      [optional] coeff a of LSF: y = ax^3 + bx^2 + cx + d
+ * \param[out]   pb      [optional] coeff b of LSF
+ * \param[out]   pc      [optional] coeff c of LSF
+ * \param[out]   pd      [optional] coeff d of LSF
+ * \param[out]   pnafit  [optional] numa of least square fit
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -1239,7 +1254,7 @@ l_float32   g[3];
  *          Get the nax array using ptaGetArrays(pta, &nax, NULL);
  * </pre>
  */
-l_int32
+l_ok
 ptaGetCubicLSF(PTA        *pta,
                l_float32  *pa,
                l_float32  *pb,
@@ -1335,13 +1350,13 @@ l_float32   g[4];
  * \brief   ptaGetQuarticLSF()
  *
  * \param[in]    pta
- * \param[out]   pa  [optional] coeff a of LSF:
- *                        y = ax^4 + bx^3 + cx^2 + dx + e
- * \param[out]   pb  [optional] coeff b of LSF
- * \param[out]   pc  [optional] coeff c of LSF
- * \param[out]   pd  [optional] coeff d of LSF
- * \param[out]   pe  [optional] coeff e of LSF
- * \param[out]   pnafit [optional] numa of least square fit
+ * \param[out]   pa      [optional] coeff a of LSF:
+ *                            y = ax^4 + bx^3 + cx^2 + dx + e
+ * \param[out]   pb      [optional] coeff b of LSF
+ * \param[out]   pc      [optional] coeff c of LSF
+ * \param[out]   pd      [optional] coeff d of LSF
+ * \param[out]   pe      [optional] coeff e of LSF
+ * \param[out]   pnafit  [optional] numa of least square fit
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -1369,7 +1384,7 @@ l_float32   g[4];
  *          Get the nax array using ptaGetArrays(pta, &nax, NULL);
  * </pre>
  */
-l_int32
+l_ok
 ptaGetQuarticLSF(PTA        *pta,
                  l_float32  *pa,
                  l_float32  *pb,
@@ -1484,13 +1499,13 @@ l_float32   g[5];
  * \brief   ptaNoisyLinearLSF()
  *
  * \param[in]    pta
- * \param[in]    factor reject outliers with error greater than this
- *                      number of medians; typically ~ 3
- * \param[out]   pptad [optional] with outliers removed
- * \param[out]   pa  [optional] slope a of least square fit: y = ax + b
- * \param[out]   pb  [optional] intercept b of least square fit
- * \param[out]   pmederr [optional] median error
- * \param[out]   pnafit [optional] numa of least square fit to ptad
+ * \param[in]    factor    reject outliers with error greater than this
+ *                         number of medians; typically ~ 3
+ * \param[out]   pptad     [optional] with outliers removed
+ * \param[out]   pa        [optional] slope a of least square fit: y = ax + b
+ * \param[out]   pb        [optional] intercept b of least square fit
+ * \param[out]   pmederr   [optional] median error
+ * \param[out]   pnafit    [optional] numa of least square fit to ptad
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -1505,7 +1520,7 @@ l_float32   g[5];
  *          is likely to be.
  * </pre>
  */
-l_int32
+l_ok
 ptaNoisyLinearLSF(PTA        *pta,
                   l_float32   factor,
                   PTA       **pptad,
@@ -1574,14 +1589,14 @@ PTA       *ptad;
  * \brief   ptaNoisyQuadraticLSF()
  *
  * \param[in]    pta
- * \param[in]    factor reject outliers with error greater than this
- *                      number of medians; typically ~ 3
- * \param[out]   pptad [optional] with outliers removed
- * \param[out]   pa  [optional] coeff a of LSF: y = ax^2 + bx + c
- * \param[out]   pb  [optional] coeff b of LSF: y = ax^2 + bx + c
- * \param[out]   pc  [optional] coeff c of LSF: y = ax^2 + bx + c
- * \param[out]   pmederr [optional] median error
- * \param[out]   pnafit [optional] numa of least square fit to ptad
+ * \param[in]    factor    reject outliers with error greater than this
+ *                         number of medians; typically ~ 3
+ * \param[out]   pptad     [optional] with outliers removed
+ * \param[out]   pa        [optional] coeff a of LSF: y = ax^2 + bx + c
+ * \param[out]   pb        [optional] coeff b of LSF: y = ax^2 + bx + c
+ * \param[out]   pc        [optional] coeff c of LSF: y = ax^2 + bx + c
+ * \param[out]   pmederr   [optional] median error
+ * \param[out]   pnafit    [optional] numa of least square fit to ptad
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -1592,7 +1607,7 @@ PTA       *ptad;
  *          a quadratic LSF on the resulting points.
  * </pre>
  */
-l_int32
+l_ok
 ptaNoisyQuadraticLSF(PTA        *pta,
                      l_float32   factor,
                      PTA       **pptad,
@@ -1667,12 +1682,12 @@ PTA       *ptad;
 /*!
  * \brief   applyLinearFit()
  *
- * \param[in]   a, b linear fit coefficients
+ * \param[in]   a, b    linear fit coefficients
  * \param[in]   x
- * \param[out]  py y = a * x + b
+ * \param[out]  py      y = a * x + b
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 applyLinearFit(l_float32   a,
                   l_float32   b,
                   l_float32   x,
@@ -1691,12 +1706,12 @@ applyLinearFit(l_float32   a,
 /*!
  * \brief   applyQuadraticFit()
  *
- * \param[in]   a, b, c quadratic fit coefficients
+ * \param[in]   a, b, c    quadratic fit coefficients
  * \param[in]   x
- * \param[out]  py y = a * x^2 + b * x + c
+ * \param[out]  py         y = a * x^2 + b * x + c
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 applyQuadraticFit(l_float32   a,
                   l_float32   b,
                   l_float32   c,
@@ -1716,12 +1731,12 @@ applyQuadraticFit(l_float32   a,
 /*!
  * \brief   applyCubicFit()
  *
- * \param[in]   a, b, c, d cubic fit coefficients
+ * \param[in]   a, b, c, d   cubic fit coefficients
  * \param[in]   x
- * \param[out]  py y = a * x^3 + b * x^2  + c * x + d
+ * \param[out]  py           y = a * x^3 + b * x^2  + c * x + d
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 applyCubicFit(l_float32   a,
               l_float32   b,
               l_float32   c,
@@ -1742,12 +1757,12 @@ applyCubicFit(l_float32   a,
 /*!
  * \brief   applyQuarticFit()
  *
- * \param[in]   a, b, c, d, e quartic fit coefficients
+ * \param[in]   a, b, c, d, e   quartic fit coefficients
  * \param[in]   x
- * \param[out]  py y = a * x^4 + b * x^3  + c * x^2 + d * x + e
+ * \param[out]  py              y = a * x^4 + b * x^3  + c * x^2 + d * x + e
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 applyQuarticFit(l_float32   a,
                 l_float32   b,
                 l_float32   c,
@@ -1775,10 +1790,10 @@ l_float32  x2;
 /*!
  * \brief   pixPlotAlongPta()
  *
- * \param[in]   pixs any depth
- * \param[in]   pta set of points on which to plot
- * \param[in]   outformat GPLOT_PNG, GPLOT_PS, GPLOT_EPS, GPLOT_LATEX
- * \param[in]   title [optional] for plot; can be null
+ * \param[in]   pixs        any depth
+ * \param[in]   pta         set of points on which to plot
+ * \param[in]   outformat   GPLOT_PNG, GPLOT_PS, GPLOT_EPS, GPLOT_LATEX
+ * \param[in]   title       [optional] for plot; can be null
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -1788,7 +1803,7 @@ l_float32  x2;
  *      (3) If the image is RGB, three separate plots are generated.
  * </pre>
  */
-l_int32
+l_ok
 pixPlotAlongPta(PIX         *pixs,
                 PTA         *pta,
                 l_int32      outformat,
@@ -1879,8 +1894,8 @@ PIX            *pixt;
 /*!
  * \brief   ptaGetPixelsFromPix()
  *
- * \param[in]    pixs 1 bpp
- * \param[in]    box [optional] can be null
+ * \param[in]    pixs     1 bpp
+ * \param[in]    box      [optional] can be null
  * \return  pta, or NULL on error
  *
  * <pre>
@@ -1932,7 +1947,7 @@ PTA       *pta;
  * \brief   pixGenerateFromPta()
  *
  * \param[in]    pta
- * \param[in]    w, h of pix
+ * \param[in]    w, h    of pix
  * \return  pix 1 bpp, or NULL on error
  *
  * <pre>
@@ -1972,8 +1987,8 @@ PIX     *pix;
 /*!
  * \brief   ptaGetBoundaryPixels()
  *
- * \param[in]    pixs 1 bpp
- * \param[in]    type L_BOUNDARY_FG, L_BOUNDARY_BG
+ * \param[in]    pixs    1 bpp
+ * \param[in]    type    L_BOUNDARY_FG, L_BOUNDARY_BG
  * \return  pta, or NULL on error
  *
  * <pre>
@@ -2012,11 +2027,11 @@ PTA  *pta;
 /*!
  * \brief   ptaaGetBoundaryPixels()
  *
- * \param[in]    pixs 1 bpp
- * \param[in]    type L_BOUNDARY_FG, L_BOUNDARY_BG
- * \param[in]    connectivity 4 or 8
- * \param[out]   pboxa [optional] bounding boxes of the c.c.
- * \param[out]   ppixa [optional] pixa of the c.c.
+ * \param[in]    pixs          1 bpp
+ * \param[in]    type          L_BOUNDARY_FG, L_BOUNDARY_BG
+ * \param[in]    connectivity  4 or 8
+ * \param[out]   pboxa         [optional] bounding boxes of the c.c.
+ * \param[out]   ppixa         [optional] pixa of the c.c.
  * \return  ptaa, or NULL on error
  *
  * <pre>
@@ -2097,8 +2112,8 @@ PTAA    *ptaa;
 /*!
  * \brief   ptaaIndexLabeledPixels()
  *
- * \param[in]    pixs 32 bpp, of indices of c.c.
- * \param[out]   pncc [optional] number of connected components
+ * \param[in]    pixs     32 bpp, of indices of c.c.
+ * \param[out]   pncc     [optional] number of connected components
  * \return  ptaa, or NULL on error
  *
  * <pre>
@@ -2161,9 +2176,9 @@ PTAA      *ptaa;
 /*!
  * \brief   ptaGetNeighborPixLocs()
  *
- * \param[in]    pixs any depth
- * \param[in]    x, y pixel from which we search for nearest neighbors
- *              conn (4 or 8 connectivity
+ * \param[in]    pixs    any depth
+ * \param[in]    x, y    pixel from which we search for nearest neighbors
+ * \param[in]    conn    4 or 8 connectivity
  * \return  pta, or NULL on error
  *
  * <pre>
@@ -2294,7 +2309,7 @@ PTA       *pta;
  * \param[out]  pnay    addr of nay
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 ptaConvertToNuma(PTA    *pta,
                  NUMA  **pnax,
                  NUMA  **pnay)
@@ -2329,9 +2344,9 @@ l_float32  valx, valy;
 /*!
  * \brief   pixDisplayPta()
  *
- * \param[in]    pixd can be same as pixs or NULL; 32 bpp if in-place
- * \param[in]    pixs 1, 2, 4, 8, 16 or 32 bpp
- * \param[in]    pta of path to be plotted
+ * \param[in]    pixd    can be same as pixs or NULL; 32 bpp if in-place
+ * \param[in]    pixs    1, 2, 4, 8, 16 or 32 bpp
+ * \param[in]    pta     of path to be plotted
  * \return  pixd 32 bpp RGB version of pixs, with path in green.
  *
  * <pre>
@@ -2389,12 +2404,12 @@ l_uint32  rpixel, gpixel, bpixel;
 /*!
  * \brief   pixDisplayPtaaPattern()
  *
- * \param[in]    pixd 32 bpp
- * \param[in]    pixs 1, 2, 4, 8, 16 or 32 bpp; 32 bpp if in place
- * \param[in]    ptaa giving locations at which the pattern is displayed
- * \param[in]    pixp 1 bpp pattern to be placed such that its reference
- *                    point co-locates with each point in pta
- * \param[in]    cx, cy reference point in pattern
+ * \param[in]    pixd     32 bpp
+ * \param[in]    pixs     1, 2, 4, 8, 16 or 32 bpp; 32 bpp if in place
+ * \param[in]    ptaa     giving locations at which the pattern is displayed
+ * \param[in]    pixp     1 bpp pattern to be placed such that its reference
+ *                        point co-locates with each point in pta
+ * \param[in]    cx, cy   reference point in pattern
  * \return  pixd 32 bpp RGB version of pixs.
  *
  * <pre>
@@ -2456,13 +2471,13 @@ PTA      *pta;
 /*!
  * \brief   pixDisplayPtaPattern()
  *
- * \param[in]    pixd can be same as pixs or NULL; 32 bpp if in-place
- * \param[in]    pixs 1, 2, 4, 8, 16 or 32 bpp
- * \param[in]    pta giving locations at which the pattern is displayed
- * \param[in]    pixp 1 bpp pattern to be placed such that its reference
- *                    point co-locates with each point in pta
- * \param[in]    cx, cy reference point in pattern
- * \param[in]    color in 0xrrggbb00 format
+ * \param[in]    pixd     can be same as pixs or NULL; 32 bpp if in-place
+ * \param[in]    pixs     1, 2, 4, 8, 16 or 32 bpp
+ * \param[in]    pta      giving locations at which the pattern is displayed
+ * \param[in]    pixp     1 bpp pattern to be placed such that its reference
+ *                        point co-locates with each point in pta
+ * \param[in]    cx, cy   reference point in pattern
+ * \param[in]    color    in 0xrrggbb00 format
  * \return  pixd 32 bpp RGB version of pixs.
  *
  * <pre>
@@ -2522,11 +2537,12 @@ PTA     *ptat;
 /*!
  * \brief   ptaReplicatePattern()
  *
- * \param[in]    ptas "sparse" input pta
- * \param[in]    pixp [optional] 1 bpp pattern, to be replicated in output pta
- * \param[in]    ptap [optional] set of pts, to be replicated in output pta
- * \param[in]    cx, cy reference point in pattern
- * \param[in]    w, h clipping sizes for output pta
+ * \param[in]    ptas    "sparse" input pta
+ * \param[in]    pixp    [optional] 1 bpp pattern, to be replicated
+ *                                  in output pta
+ * \param[in]    ptap    [optional] set of pts, to be replicated in output pta
+ * \param[in]    cx, cy  reference point in pattern
+ * \param[in]    w, h    clipping sizes for output pta
  * \return  ptad with all points of replicated pattern, or NULL on error
  *
  * <pre>
@@ -2585,8 +2601,8 @@ PTA     *ptat, *ptad;
 /*!
  * \brief   pixDisplayPtaa()
  *
- * \param[in]    pixs 1, 2, 4, 8, 16 or 32 bpp
- * \param[in]    ptaa array of paths to be plotted
+ * \param[in]    pixs    1, 2, 4, 8, 16 or 32 bpp
+ * \param[in]    ptaa    array of paths to be plotted
  * \return  pixd 32 bpp RGB version of pixs, with paths plotted
  *                    in different colors, or NULL on error
  */
