@@ -141,15 +141,15 @@ static char *l_genDescrString(const char *filein, l_int32 ifunc, l_int32 itype);
 /*!
  * \brief   strcodeCreate()
  *
- * \param[in]    fileno integer that labels the two output files
+ * \param[in]    fileno    integer that labels the two output files
  * \return  initialized L_StrCode, or NULL on error
  *
  * <pre>
  * Notes:
  *      (1) This struct exists to build two files containing code for
  *          any number of data objects.  The two files are named
- *             autogen.<fileno>.c
- *             autogen.<fileno>.h
+ *             autogen.[fileno].c
+ *             autogen.[fileno].h
  * </pre>
  */
 L_STRCODE *
@@ -175,7 +175,7 @@ L_STRCODE  *strcode;
 /*!
  * \brief   strcodeDestroy()
  *
- * \param[out]  pstrcode &strcode is set to null after destroying the sarrays
+ * \param[out]  pstrcode    will be set to null after destroying the sarrays
  * \return  void
  */
 static void
@@ -205,9 +205,9 @@ L_STRCODE  *strcode;
 /*!
  * \brief   strcodeCreateFromFile()
  *
- * \param[in]    filein containing filenames of serialized data
- * \param[in]    fileno integer that labels the two output files
- * \param[in]    outdir [optional] if null, files are made in /tmp/lept/auto
+ * \param[in]    filein    containing filenames of serialized data
+ * \param[in]    fileno    integer that labels the two output files
+ * \param[in]    outdir    [optional] if null, files are made in /tmp/lept/auto
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -215,11 +215,11 @@ L_STRCODE  *strcode;
  *      (1) The %filein has one filename on each line.
  *          Comment lines begin with "#".
  *      (2) The output is 2 files:
- *             autogen.<fileno>.c
- *             autogen.<fileno>.h
+ *             autogen.[fileno].c
+ *             autogen.[fileno].h
  * </pre>
  */
-l_int32
+l_ok
 strcodeCreateFromFile(const char  *filein,
                       l_int32      fileno,
                       const char  *outdir)
@@ -270,22 +270,22 @@ L_STRCODE   *strcode;
 /*!
  * \brief   strcodeGenerate()
  *
- * \param[in]    strcode for accumulating data
- * \param[in]    filein input file with serialized data
- * \param[in]    type of data; use the typedef string
+ * \param[in]    strcode    for accumulating data
+ * \param[in]    filein     input file with serialized data
+ * \param[in]    type       of data; use the typedef string
  * \return  0 if OK, 1 on error.
  *
  * <pre>
  * Notes:
  *      (1) The generated function name is
- *            l_autodecode_<fileno>()
- *          where <fileno> is the index label for the pair of output files.
+ *            l_autodecode_[fileno]()
+ *          where [fileno] is the index label for the pair of output files.
  *      (2) To deserialize this data, the function is called with the
  *          argument 'ifunc', which increments each time strcodeGenerate()
  *          is called.
  * </pre>
  */
-l_int32
+l_ok
 strcodeGenerate(L_STRCODE   *strcode,
                 const char  *filein,
                 const char  *type)
@@ -328,8 +328,9 @@ l_int32  itype;
 /*!
  * \brief   strcodeFinalize()
  *
- * \param[in,out]  pstrcode destroys after .c and .h files have been generated
- * \param[in]      outdir [optional] if NULL, files are made in /tmp/lept/auto
+ * \param[in,out]  pstrcode   destroys and sets to null after .c and .h files
+ *                            have been generated
+ * \param[in]      outdir     [optional] if NULL, make files in /tmp/lept/auto
  * \return  void
  */
 l_int32
@@ -510,8 +511,8 @@ SARRAY     *sa1, *sa2, *sa3;
  * \brief   l_getStructStrFromFile()
  *
  * \param[in]    filename
- * \param[in]    field  (L_STR_TYPE, L_STR_NAME, L_STR_READER, L_STR_MEMREADER)
- * \param[out]   pstr  struct string for this file
+ * \param[in]    field   (L_STR_TYPE, L_STR_NAME, L_STR_READER, L_STR_MEMREADER)
+ * \param[out]   pstr    struct string for this file
  * \return  0 if found, 1 on error.
  *
  * <pre>
@@ -519,6 +520,7 @@ SARRAY     *sa1, *sa2, *sa3;
  *      (1) For example, if %field == L_STR_NAME, and the file is a serialized
  *          pixa, this will return "Pixa", the name of the struct.
  *      (2) Caller must free the returned string.
+ * </pre>
  */
 l_int32
 l_getStructStrFromFile(const char  *filename,
@@ -558,8 +560,8 @@ l_int32  index;
 /*!
  * \brief   l_getIndexFromType()
  *
- * \param[in]    type e.g., "PIXA"
- * \param[out]   pindex found index
+ * \param[in]    type     e.g., "PIXA"
+ * \param[out]   pindex   found index
  * \return  0 if found, 1 if not.
  *
  * <pre>
@@ -596,8 +598,8 @@ l_int32  i, found;
 /*!
  * \brief   l_getIndexFromStructname()
  *
- * \param[in]    sn structname e.g., "Pixa"
- * \param[out]   pindex found index
+ * \param[in]    sn       structname e.g., "Pixa"
+ * \param[out]   pindex   found index
  * \return  0 if found, 1 if not.
  *
  * <pre>
@@ -637,7 +639,7 @@ l_int32  i, found;
  * \brief   l_getIndexFromFile()
  *
  * \param[in]    filename
- * \param[out]   pindex found index
+ * \param[out]   pindex     found index
  * \return  0 if found, 1 on error.
  */
 static l_int32
@@ -691,8 +693,8 @@ SARRAY  *sa;
 /*!
  * \brief   l_genDataString()
  *
- * \param[in]    filein input file of serialized data
- * \param[in]    ifunc index into set of functions in output file
+ * \param[in]    filein   input file of serialized data
+ * \param[in]    ifunc    index into set of functions in output file
  * \return  encoded ascii data string, or NULL on error reading from file
  */
 static char *
@@ -727,7 +729,7 @@ SARRAY   *sa;
     snprintf(buf, sizeof(buf), "static const char *l_strdata_%d =\n", ifunc);
     sarrayAddString(sa, buf, L_COPY);
     sarrayAddString(sa, cdata2, L_INSERT);
-    sarrayAddString(sa, (char *)";\n", L_COPY);
+    sarrayAddString(sa, ";\n", L_COPY);
     cdata3 = sarrayToString(sa, 0);
     sarrayDestroy(&sa);
     return cdata3;
@@ -737,8 +739,8 @@ SARRAY   *sa;
 /*!
  * \brief   l_genCaseString()
  *
- * \param[in]    ifunc index into set of functions in generated file
- * \param[in]    itype index into type of function to be used
+ * \param[in]    ifunc   index into set of functions in generated file
+ * \param[in]    itype   index into type of function to be used
  * \return  case string for this decoding function
  *
  * <pre>
@@ -775,9 +777,9 @@ char  *code = NULL;
 /*!
  * \brief   l_genDescrString()
  *
- * \param[in]    filein input file of serialized data
- * \param[in]    ifunc index into set of functions in generated file
- * \param[in]    itype index into type of function to be used
+ * \param[in]    filein   input file of serialized data
+ * \param[in]    ifunc    index into set of functions in generated file
+ * \param[in]    itype    index into type of function to be used
  * \return  description string for this decoding function
  */
 static char *
